% Auto-generated chapter 10 for nasai
% Hadiths in this chapter: 99

\hadithdefcmd{nasai}{777}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَهَنَّادُ بْنُ السَّرِيِّ، عَنْ حُسَيْنِ بْنِ عَلِيٍّ، عَنْ زَائِدَةَ، عَنْ عَاصِمٍ، عَنْ زِرٍّ، عَنْ عَبْدِ اللَّهِ، قَالَ لَمَّا قُبِضَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَتِ الأَنْصَارُ مِنَّا أَمِيرٌ وَمِنْكُمْ أَمِيرٌ ‏.‏ فَأَتَاهُمْ عُمَرُ فَقَالَ أَلَسْتُمْ تَعْلَمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ أَمَرَ أَبَا بَكْرٍ أَنْ يُصَلِّيَ بِالنَّاسِ فَأَيُّكُمْ تَطِيبُ نَفْسُهُ أَنْ يَتَقَدَّمَ أَبَا بَكْرٍ قَالُوا نَعُوذُ بِاللَّهِ أَنْ نَتَقَدَّمَ أَبَا بَكْرٍ ‏.‏\hadithno{777}\hadithgrade{Abu Ghuddah: Hasan Isnaad; Al-Albani: Hasan Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Abdullah said:"When the Messenger of Allah(ﷺ) passed away, the Ansar said: 'Let there be an Amir from among us and an Amir from among you.' Then 'Umar came to them and said: 'Do you not know that the Messenger of Allah(ﷺ) commanded Abu Bakr to lead the people in prayer? Who mong you could accept to put himself ahead of Abu Bakr?' They said: 'We seek refuge with Allah from putting ourselves ahead of Abu Bakr}}
\hadithdefcmd{nasai}{778}{أَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي الْعَالِيَةِ الْبَرَّاءِ، قَالَ أَخَّرَ زِيَادٌ الصَّلاَةَ فَأَتَانِي ابْنُ صَامِتٍ فَأَلْقَيْتُ لَهُ كُرْسِيًّا فَجَلَسَ عَلَيْهِ فَذَكَرْتُ لَهُ صُنْعَ زِيَادٍ فَعَضَّ عَلَى شَفَتَيْهِ وَضَرَبَ عَلَى فَخِذِي وَقَالَ إِنِّي سَأَلْتُ أَبَا ذَرٍّ كَمَا سَأَلْتَنِي فَضَرَبَ فَخِذِي كَمَا ضَرَبْتُ فَخِذَكَ وَقَالَ إِنِّي سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم كَمَا سَأَلْتَنِي فَضَرَبَ فَخِذِي كَمَا ضَرَبْتُ فَخِذَكَ فَقَالَ عَلَيْهِ الصَّلاَةُ وَالسَّلاَمُ ‏ "‏ صَلِّ الصَّلاَةَ لِوَقْتِهَا فَإِنْ أَدْرَكْتَ مَعَهُمْ فَصَلِّ وَلاَ تَقُلْ إِنِّي صَلَّيْتُ فَلاَ أُصَلِّي ‏"‏ ‏.‏\hadithno{778}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Aliyah Al-Barra said:"Ziyad delayed the prayer, then Ibn Samit came to me and I gave him a chair and he sat on it. I told him what Ziyad had done and he bit his lip (in disapproval), and he struck me on the thigh and said: 'I asked Abu Dharr the same question you asked me, and he struck me on the thigh as I struck you on the thigh and said: I asked the Messenger of Allah (ﷺ) the same question as you have asked me and he struck me on the thigh as I have struck you on the thigh and said: Offer the prayer on time, and if you catch up with them, then pray with them, and do not say: 'I have already prayed so I will not pray(now)}}
\hadithdefcmd{nasai}{779}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ عَاصِمٍ، عَنْ زِرٍّ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَعَلَّكُمْ سَتُدْرِكُونَ أَقْوَامًا يُصَلُّونَ الصَّلاَةَ لِغَيْرِ وَقْتِهَا فَإِنْ أَدْرَكْتُمُوهُمْ فَصَلُّوا الصَّلاَةَ لِوَقْتِهَا وَصَلُّوا مَعَهُمْ وَاجْعَلُوهَا سُبْحَةً ‏"‏ ‏.‏\hadithno{779}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullih said:"The Messenger of Allah (ﷺ) said: 'You may live to meet people who will be offering the prayer outside its (prayer) time. If you meet them, then offer the prayer on time, then pray with them and make that a voluntary prayer}}
\hadithdefcmd{nasai}{780}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ أَنْبَأَنَا فُضَيْلُ بْنُ عِيَاضٍ، عَنِ الأَعْمَشِ، عَنْ إِسْمَاعِيلَ بْنِ رَجَاءٍ، عَنْ أَوْسِ بْنِ ضَمْعَجٍ، عَنْ أَبِي مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَؤُمُّ الْقَوْمَ أَقْرَؤُهُمْ لِكِتَابِ اللَّهِ فَإِنْ كَانُوا فِي الْقِرَاءَةِ سَوَاءً فَأَقْدَمُهُمْ فِي الْهِجْرَةِ فَإِنْ كَانُوا فِي الْهِجْرَةِ سَوَاءً فَأَعْلَمُهُمْ بِالسُّنَّةِ فَإِنْ كَانُوا فِي السُّنَّةِ سَوَاءً فَأَقْدَمُهُمْ سِنًّا وَلاَ تَؤُمَّ الرَّجُلَ فِي سُلْطَانِهِ وَلاَ تَقْعُدْ عَلَى تَكْرِمَتِهِ إِلاَّ أَنْ يَأْذَنَ لَكَ ‏"‏ ‏.‏\hadithno{780}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Masud said:"The Messenger of Allah(ﷺ)said: 'Let the one who has most knowledge of the Book of Allah lead the people in prayer. If they are equal in terms of knowledge of the Qur'h, let the one who emigrated first (lead them). If they are equal in terms of emigration, let the one who has more knowledge of the Sunnah, (lead them). If they are equal in terms of knowledge of the Sunnah, let the one who is oldest (lead them). Do not lead a man in prayer in his place of authority, and do not sit in his place of honor, unless he gives you permission}}
\hadithdefcmd{nasai}{781}{أَخْبَرَنَا حَاجِبُ بْنُ سُلَيْمَانَ الْمَنْبِجِيُّ، عَنْ وَكِيعٍ، عَنْ سُفْيَانَ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ مَالِكِ بْنِ الْحُوَيْرِثِ، قَالَ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنَا وَابْنُ عَمٍّ لِي - وَقَالَ مَرَّةً أَنَا وَصَاحِبٌ لِي - فَقَالَ ‏ "‏ إِذَا سَافَرْتُمَا فَأَذِّنَا وَأَقِيمَا وَلْيَؤُمَّكُمَا أَكْبَرُكُمَا ‏"‏ ‏.‏\hadithno{781}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Malik bin Al-Huwairith said:"I came to the Messenger of Allah (ﷺ) with a cousin of mine" - once he said, "with a friend of mine" - and he said: 'When you travel, call the Adhan and Iqamah, and let the older of you lead the prayer}}
\hadithdefcmd{nasai}{782}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، عَنْ يَحْيَى، عَنْ هِشَامٍ، قَالَ حَدَّثَنَا قَتَادَةُ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا كَانُوا ثَلاَثَةً فَلْيَؤُمَّهُمْ أَحَدُهُمْ وَأَحَقُّهُمْ بِالإِمَامَةِ أَقْرَؤُهُمْ ‏"‏ ‏.‏\hadithno{782}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Sa'eed that the Prophet (ﷺ) said:"when there are three people let one of them lead the prayer, and the one who is most entitled to lead the prayer is the one who has most knowledge of the Qur'an}}
\hadithdefcmd{nasai}{783}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ مُحَمَّدٍ التَّيْمِيُّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ شُعْبَةَ، عَنْ إِسْمَاعِيلَ بْنِ رَجَاءٍ، عَنْ أَوْسِ بْنِ ضَمْعَجٍ، عَنْ أَبِي مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يُؤَمُّ الرَّجُلُ فِي سُلْطَانِهِ وَلاَ يُجْلَسُ عَلَى تَكْرِمَتِهِ إِلاَّ بِإِذْنِهِ ‏"‏ ‏.‏\hadithno{783}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{It was narrated that Abu Masud said:"The Messenger of Allah (ﷺ) said: 'A man should not be led in prayer in his place of authority, and no one should sit in his place of honor except with his permission}}
\hadithdefcmd{nasai}{784}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا يَعْقُوبُ، - وَهُوَ ابْنُ عَبْدِ الرَّحْمَنِ - عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَلَغَهُ أَنَّ بَنِي عَمْرِو بْنِ عَوْفٍ كَانَ بَيْنَهُمْ شَىْءٌ فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِيُصْلِحَ بَيْنَهُمْ فِي أُنَاسٍ مَعَهُ فَحُبِسَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَحَانَتِ الأُولَى فَجَاءَ بِلاَلٌ إِلَى أَبِي بَكْرٍ فَقَالَ يَا أَبَا بَكْرٍ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ حُبِسَ وَقَدْ حَانَتِ الصَّلاَةُ فَهَلْ لَكَ أَنْ تَؤُمَّ النَّاسَ قَالَ نَعَمْ إِنْ شِئْتَ ‏.‏ فَأَقَامَ بِلاَلٌ وَتَقَدَّمَ أَبُو بَكْرٍ فَكَبَّرَ بِالنَّاسِ وَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَمْشِي فِي الصُّفُوفِ حَتَّى قَامَ فِي الصَّفِّ وَأَخَذَ النَّاسُ فِي التَّصْفِيقِ وَكَانَ أَبُو بَكْرٍ لاَ يَلْتَفِتُ فِي صَلاَتِهِ فَلَمَّا أَكْثَرَ النَّاسُ الْتَفَتَ فَإِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَشَارَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْمُرُهُ أَنْ يُصَلِّيَ فَرَفَعَ أَبُو بَكْرٍ يَدَيْهِ فَحَمِدَ اللَّهَ عَزَّ وَجَلَّ وَرَجَعَ الْقَهْقَرَى وَرَاءَهُ حَتَّى قَامَ فِي الصَّفِّ فَتَقَدَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَلَّى بِالنَّاسِ فَلَمَّا فَرَغَ أَقْبَلَ عَلَى النَّاسِ فَقَالَ ‏ "‏ يَا أَيُّهَا النَّاسُ مَا لَكُمْ حِينَ نَابَكُمْ شَىْءٌ فِي الصَّلاَةِ أَخَذْتُمْ فِي التَّصْفِيقِ إِنَّمَا التَّصْفِيقُ لِلنِّسَاءِ مَنْ نَابَهُ شَىْءٌ فِي صَلاَتِهِ فَلْيَقُلْ سُبْحَانَ اللَّهِ فَإِنَّهُ لاَ يَسْمَعُهُ أَحَدٌ حِينَ يَقُولُ سُبْحَانَ اللَّهِ إِلاَّ الْتَفَتَ إِلَيْهِ يَا أَبَا بَكْرٍ مَا مَنَعَكَ أَنْ تُصَلِّيَ لِلنَّاسِ حِينَ أَشَرْتُ إِلَيْكَ ‏"‏ ‏.‏ قَالَ أَبُو بَكْرٍ مَا كَانَ يَنْبَغِي لاِبْنِ أَبِي قُحَافَةَ أَنْ يُصَلِّيَ بَيْنَ يَدَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{784}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Sahl bin Sa'd that the Messenger of Allah (ﷺ) heard that there was a dispute among Banu 'Amr bin 'Awf, so he went to them with some other people to reconcile between them. The Messenger of Allah (ﷺ) was delayed there, and the time for Zuhr came. Bilal came to Abu Bakr and said to him:"The Messenger of Allah (ﷺ) has been delayed (there) and the time for prayer has come, will you lead the people in prayer?" Abu Bakr said: 'Yes, if you wish.' Bilal said the Iqamah and Abu Bakr went forward and said the Takbir for the people. Then the Messenger of Allah(ﷺ) came, passing through the rows (of praying people) and stood in the (first) row and the people started clapping. Abu Bakr would never glance sideways in his prayer but when the people clapped so much he looked back and (ﷺ)Messenger of Allah (ﷺ). The Messenger of Allah(ﷺ) gestured to him to carry on praying. Aha Bakr raised his hands praising Allah the Mighty and Sublime, and retreated till he reached the (first) row. Then the Messenger ofAllah(ﷺ) went forward and led the people in the prayer. When he completed the prayer he turned to face the people and said: '0 people, why did you start clapping when something unusual happened to you in the prayer? Clapping is only for women. So whoever among you comes across something in the prayer should say: 'Subhan Allah' for there is none who will not turn round when they hear him saying Subhan Allah. 0 Abu Bakr! What prevented you from leading the people in the prayer when I gestured to you to do so?' Abu Bakr replied: 'It is not fitting for the son of Abu Quhafah to lead the prayer in the presence of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{nasai}{785}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسٍ، قَالَ آخِرُ صَلاَةٍ صَلاَّهَا رَسُولُ اللَّهِ صلى الله عليه وسلم مَعَ الْقَوْمِ صَلَّى فِي ثَوْبٍ وَاحِدٍ مُتَوَشِّحًا خَلْفَ أَبِي بَكْرٍ ‏.‏\hadithno{785}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas said:"In the last prayer that the Messenger of Allah(ﷺ) prayed with the people, he prayed wrapped up in a single garment, behind Abu Bakr}}
\hadithdefcmd{nasai}{786}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا بَكْرُ بْنُ عِيسَى، - صَاحِبُ الْبُصْرَى - قَالَ سَمِعْتُ شُعْبَةَ، يَذْكُرُ عَنْ نُعَيْمِ بْنِ أَبِي هِنْدٍ، عَنْ أَبِي وَائِلٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ أَبَا بَكْرٍ، صَلَّى لِلنَّاسِ وَرَسُولُ اللَّهِ صلى الله عليه وسلم فِي الصَّفِّ ‏.‏\hadithno{786}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Aisha that Abu Bakr led the people in prayer and the Messenger of Allah (ﷺ)was in the row}}
\hadithdefcmd{nasai}{787}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ أَبَانَ بْنِ يَزِيدَ، قَالَ حَدَّثَنَا بُدَيْلُ بْنُ مَيْسَرَةَ، قَالَ حَدَّثَنَا أَبُو عَطِيَّةَ، مَوْلًى لَنَا عَنْ مَالِكِ بْنِ الْحُوَيْرِثِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا زَارَ أَحَدُكُمْ قَوْمًا فَلاَ يُصَلِّيَنَّ بِهِمْ ‏"‏ ‏.‏\hadithno{787}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Malik bin Al-Huwairith said:"I heard the Messenger of Allah (ﷺ) say: 'When any one of you visits some people,he should not lead them in prayer}}
\hadithdefcmd{nasai}{788}{أَخْبَرَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنَا مَالِكٌ، ح قَالَ وَحَدَّثَنَا الْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ مَحْمُودِ بْنِ الرَّبِيعِ، ‏.‏ أَنَّ عِتْبَانَ بْنَ مَالِكٍ، كَانَ يَؤُمُّ قَوْمَهُ وَهُوَ أَعْمَى وَأَنَّهُ قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم إِنَّهَا تَكُونُ الظُّلْمَةُ وَالْمَطَرُ وَالسَّيْلُ وَأَنَا رَجُلٌ ضَرِيرُ الْبَصَرِ فَصَلِّ يَا رَسُولَ اللَّهِ فِي بَيْتِي مَكَانًا أَتَّخِذُهُ مُصَلًّى ‏.‏ فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَيْنَ تُحِبُّ أَنْ أُصَلِّيَ لَكَ ‏"‏ ‏.‏ فَأَشَارَ إِلَى مَكَانٍ مِنَ الْبَيْتِ فَصَلَّى فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{788}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Mahmiid bin Ar-Rabi' that 'Itbk bin Milk used to lead his people in prayer, and he was blind. He said to the Messenger of Allah (ﷺ):"Sometimes it is dark or rainy or there is a flood, and I am a blind man; 0 Messenger of Allah (ﷺ), (come and) pray in a place in my house that I may take as a prayer-place." He said: "Where would you like me to pray for you?" He showed him a place in his house, and the Messenger of Allah (ﷺ) prayed there}}
\hadithdefcmd{nasai}{789}{أَخْبَرَنَا مُوسَى بْنُ عَبْدِ الرَّحْمَنِ الْمَسْرُوقِيُّ، حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، عَنْ زَائِدَةَ، عَنْ سُفْيَانَ، عَنْ أَيُّوبَ، قَالَ حَدَّثَنِي عَمْرُو بْنُ سَلِمَةَ الْجَرْمِيُّ، قَالَ كَانَ يَمُرُّ عَلَيْنَا الرُّكْبَانُ فَنَتَعَلَّمُ مِنْهُمُ الْقُرْآنَ فَأَتَى أَبِي النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ لِيَؤُمَّكُمْ أَكْثَرُكُمْ قُرْآنًا ‏"‏ ‏.‏ فَجَاءَ أَبِي فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لِيَؤُمَّكُمْ أَكْثَرُكُمْ قُرْآنًا ‏"‏ ‏.‏ فَنَظَرُوا فَكُنْتُ أَكْثَرَهُمْ قُرْآنًا فَكُنْتُ أَؤُمُّهُمْ وَأَنَا ابْنُ ثَمَانِ سِنِينَ ‏.‏\hadithno{789}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Amr bin Salamah Al-Jarmi said:"Riders used to pass by us and we would leam the Qur'an from them. My father came to the Prophet (ﷺ) and he said: 'Let the one of you who knows most Qur'an leads the prayer.' My father came and said that the Messenger of Allah (ﷺ) had said: 'Let the one of you who knows most Quran lead you in prayer.' They looked and found that I was the one who knew most Qur'an, so I used to lead them in prayer when I was eight years old}}
\hadithdefcmd{nasai}{790}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا هُشَيْمٌ، عَنْ هِشَامِ بْنِ أَبِي عَبْدِ اللَّهِ، وَحَجَّاجُ بْنُ أَبِي عُثْمَانَ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا نُودِيَ لِلصَّلاَةِ فَلاَ تَقُومُوا حَتَّى تَرَوْنِي ‏"‏ ‏.‏\hadithno{790}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abdullah bin Abi Qatadah that his father said:"The messenger of Allah (ﷺ) said: 'When the call to prayer is given, do not stand up until you see me}}
\hadithdefcmd{nasai}{791}{أَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ أَنَسٍ، قَالَ أُقِيمَتِ الصَّلاَةُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم نَجِيٌّ لِرَجُلٍ فَمَا قَامَ إِلَى الصَّلاَةِ حَتَّى نَامَ الْقَوْمُ ‏.‏\hadithno{791}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas said:"The Iqamah for prayer was said, and the Messenger of Allah (ﷺ) was conversing privately with a man, and did not commence the prayer until the people slept}}
\hadithdefcmd{nasai}{792}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، عَنِ الزُّبَيْدِيِّ، عَنِ الزُّهْرِيِّ، وَالْوَلِيدُ، عَنِ الأَوْزَاعِيِّ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أُقِيمَتِ الصَّلاَةُ فَصَفَّ النَّاسُ صُفُوفَهُمْ وَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى إِذَا قَامَ فِي مُصَلاَّهُ ذَكَرَ أَنَّهُ لَمْ يَغْتَسِلْ فَقَالَ لِلنَّاسِ ‏ "‏ مَكَانَكُمْ ‏"‏ ‏.‏ ثُمَّ رَجَعَ إِلَى بَيْتِهِ فَخَرَجَ عَلَيْنَا يَنْطِفُ رَأْسُهُ فَاغْتَسَلَ وَنَحْنُ صُفُوفٌ ‏.‏\hadithno{792}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"The Iqamah for prayer was said and the people stood in rows, and the Messenger of Allah (ﷺ) came out. Then when he stood in the place where he prayed, he remembered that he had not performed Ghusl. He said to the people: 'Stay where you are.' Then he went back to his house, then he came out with his head dripping with water. He performed Ghusl while we were standing in our rows}}
\hadithdefcmd{nasai}{793}{أَخْبَرَنَا أَحْمَدُ بْنُ عَبْدَةَ، عَنْ حَمَّادِ بْنِ زَيْدٍ، ثُمَّ ذَكَرَ كَلِمَةً مَعْنَاهَا قَالَ حَدَّثَنَا أَبُو حَازِمٍ، قَالَ سَهْلُ بْنُ سَعْدٍ كَانَ قِتَالٌ بَيْنَ بَنِي عَمْرِو بْنِ عَوْفٍ فَبَلَغَ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم فَصَلَّى الظُّهْرَ ثُمَّ أَتَاهُمْ لِيُصْلِحَ بَيْنَهُمْ ثُمَّ قَالَ لِبِلاَلٍ ‏"‏ يَا بِلاَلُ إِذَا حَضَرَ الْعَصْرُ وَلَمْ آتِ فَمُرْ أَبَا بَكْرٍ فَلْيُصَلِّ بِالنَّاسِ ‏"‏ ‏.‏ فَلَمَّا حَضَرَتْ أَذَّنَ بِلاَلٌ ثُمَّ أَقَامَ فَقَالَ لأَبِي بَكْرٍ رضى الله عنه تَقَدَّمْ ‏.‏ فَتَقَدَّمَ أَبُو بَكْرٍ فَدَخَلَ فِي الصَّلاَةِ ثُمَّ جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَجَعَلَ يَشُقُّ النَّاسَ حَتَّى قَامَ خَلْفَ أَبِي بَكْرٍ وَصَفَّحَ الْقَوْمُ وَكَانَ أَبُو بَكْرٍ إِذَا دَخَلَ فِي الصَّلاَةِ لَمْ يَلْتَفِتْ فَلَمَّا رَأَى أَبُو بَكْرٍ التَّصْفِيحَ لاَ يُمْسَكُ عَنْهُ الْتَفَتَ فَأَوْمَأَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِهِ فَحَمِدَ اللَّهَ عَزَّ وَجَلَّ عَلَى قَوْلِ رَسُولِ اللَّهِ صلى الله عليه وسلم لَهُ امْضِهْ ثُمَّ مَشَى أَبُو بَكْرٍ الْقَهْقَرَى عَلَى عَقِبَيْهِ فَتَأَخَّرَ فَلَمَّا رَأَى ذَلِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم تَقَدَّمَ فَصَلَّى بِالنَّاسِ فَلَمَّا قَضَى صَلاَتَهُ قَالَ ‏"‏ يَا أَبَا بَكْرٍ مَا مَنَعَكَ إِذْ أَوْمَأْتُ إِلَيْكَ أَنْ لاَ تَكُونَ مَضَيْتَ ‏"‏ ‏.‏ فَقَالَ لَمْ يَكُنْ لاِبْنِ أَبِي قُحَافَةَ أَنْ يَؤُمَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ وَقَالَ لِلنَّاسِ ‏"‏ إِذَا نَابَكُمْ شَىْءٌ فَلْيُسَبِّحِ الرِّجَالُ وَلْيُصَفِّحِ النِّسَاءُ ‏"‏ ‏.‏\hadithno{793}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Sahl bin Sa'd said:"There was some fighting among Banu 'Amr bin 'Awf, and news of that reached the Prophet (ﷺ). He prayed Zuhr, then he went to them to reconcile between them. Then he said to Bilal: 'O Bilal, if the time for Asr comes and I have not come back, then tell Abu Bakr to lead the people in prayer.' When the time (for Asr) came, Bilal called the Adhan, then the Iqamah, then he said to Abu Bakr: 'Go forward. So Abu Bakr went forward and started to pray. Then the Messenger of Allah (ﷺ) came and started passing through the rows of people until he stood behind Abu Bakr, and the people clapped. Abu Bakr was such that whenever he started praying, he would never glance sideways, but when he noticed that the clapping persisted he turned around. The Messenger of Allah (ﷺ) gestured to him to carry on praying. Abu Bakr praised Allah the Mighty and Sublime for the Messenger of Allah (ﷺ) having told him to continue. Then Abu Bakr moved backward on his heels, and when the Messenger of Allah (ﷺ) saw that, he came forward and led the people in prayer. When he completed the prayer he said: 'O Abu Bakr, when I gestured to you, what kept you from continuing (to lead the people)?' He said: 'It does not befit the son of Abu Quhafah to lead the Messenger of Allah (ﷺ) in prayer.' And he (the Prophet) said to the people: 'If you notice something (during the prayer), men should say Subhan Allah and women should clap}}
\hadithdefcmd{nasai}{794}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنِ ابْنِ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سَقَطَ مِنْ فَرَسٍ عَلَى شِقِّهِ الأَيْمَنِ فَدَخَلُوا عَلَيْهِ يَعُودُونَهُ فَحَضَرَتِ الصَّلاَةُ فَلَمَّا قَضَى الصَّلاَةَ قَالَ ‏ "‏ إِنَّمَا جُعِلَ الإِمَامُ لِيُؤْتَمَّ بِهِ فَإِذَا رَكَعَ فَارْكَعُوا وَإِذَا رَفَعَ فَارْفَعُوا وَإِذَا سَجَدَ فَاسْجُدُوا وَإِذَا قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ فَقُولُوا رَبَّنَا لَكَ الْحَمْدُ ‏"‏ ‏.‏\hadithno{794}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas that the Messenger of Allah(ﷺ) fell from a horse onto his right side.They came to visit him and the time for prayer came. When the prayer was over he said:"The Imam is appointed to be followed. When he bows, then bow, when he stands up, then stand up, when he prostrates, then prostrate, and when he says Sami' Alldhu liman hamidah (Allah hears the one who praises Him), then say, Rabbanri lakal-hamd (Our Lord, to You be the praise)}}
\hadithdefcmd{nasai}{795}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ جَعْفَرِ بْنِ حَيَّانَ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَأَى فِي أَصْحَابِهِ تَأَخُّرًا فَقَالَ ‏ "‏ تَقَدَّمُوا فَأْتَمُّوا بِي وَلْيَأْتَمَّ بِكُمْ مَنْ بَعْدَكُمْ وَلاَ يَزَالُ قَوْمٌ يَتَأَخَّرُونَ حَتَّى يُؤَخِّرَهُمُ اللَّهُ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{795}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Sa'eed that the Messenger of Allah (ﷺ) saw that his companions tended to stand in the rear, so he said:"Come forward and follow me, and let those who are behind you follow your lead. If people continue to lag behind, Allah, the Mighty and Sublime, will put them back}}
\hadithdefcmd{nasai}{796}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي نَضْرَةَ، نَحْوَهُ ‏.‏\hadithno{796}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{(Another chain) from Abu Nadrah (from Abu Sa'eed) with similar narration}}
\hadithdefcmd{nasai}{797}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنِي أَبُو دَاوُدَ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنْ مُوسَى بْنِ أَبِي عَائِشَةَ، قَالَ سَمِعْتُ عُبَيْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ، يُحَدِّثُ عَنْ عَائِشَةَ، رضى الله عنها أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ أَبَا بَكْرٍ أَنْ يُصَلِّيَ بِالنَّاسِ قَالَتْ وَكَانَ النَّبِيُّ صلى الله عليه وسلم بَيْنَ يَدَىْ أَبِي بَكْرٍ فَصَلَّى قَاعِدًا وَأَبُو بَكْرٍ يُصَلِّي بِالنَّاسِ وَالنَّاسُ خَلْفَ أَبِي بَكْرٍ ‏.‏\hadithno{797}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Aisha may Allah be pleased with her, that the Messenger of Allah (ﷺ) told Abu Bakr to lead the people in prayer. She said:"The Prophet was in front of Abu Bakr and he prayed sitting down, and Abu Bakr was leading the people in prayer, and the people were behind Abu Bakr}}
\hadithdefcmd{nasai}{798}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ فَضَالَةَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَحْيَى، - يَعْنِي ابْنَ يَحْيَى - قَالَ حَدَّثَنَا حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ حُمَيْدٍ الرُّؤَاسِيُّ، عَنْ أَبِيهِ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم الظُّهْرَ وَأَبُو بَكْرٍ خَلْفَهُ فَإِذَا كَبَّرَ رَسُولُ اللَّهِ صلى الله عليه وسلم كَبَّرَ أَبُو بَكْرٍ يُسْمِعُنَا ‏.‏\hadithno{798}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah (ﷺ) led us in Zuhr prayer and Abu Bakr was behind him. When the Messenger of Allah (ﷺ) said the Takbir, Abu Bakr said the Takbir so that the people could hear}}
\hadithdefcmd{nasai}{799}{أَخْبَرَنَا مُحَمَّدُ بْنُ عُبَيْدٍ الْكُوفِيُّ، عَنْ مُحَمَّدِ بْنِ فُضَيْلٍ، عَنْ هَارُونَ بْنِ عَنْتَرَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَسْوَدِ، عَنِ الأَسْوَدِ، وَعَلْقَمَةَ، قَالاَ دَخَلْنَا عَلَى عَبْدِ اللَّهِ نِصْفَ النَّهَارِ فَقَالَ إِنَّهُ سَيَكُونُ أُمَرَاءُ يَشْتَغِلُونَ عَنْ وَقْتِ الصَّلاَةَ فَصَلُّوا لِوَقْتِهَا ‏.‏ ثُمَّ قَامَ فَصَلَّى بَيْنِي وَبَيْنَهُ فَقَالَ هَكَذَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَعَلَ ‏.‏\hadithno{799}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Al-Aswad and 'Alqamah said:"We entered upon 'Abdullah at midday and he said: 'There will be rulers who would be distracted from praying on time, so pray on time.' Then he stood up and prayed between him and I, and said: 'This is what I saw the Messenger of Allah (ﷺ) do}}
\hadithdefcmd{nasai}{800}{أَخْبَرَنَا عَبْدَةُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، قَالَ حَدَّثَنَا أَفْلَحُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا بُرَيْدَةُ بْنُ سُفْيَانَ بْنِ فَرْوَةَ الأَسْلَمِيُّ، عَنْ غُلاَمٍ، لِجَدِّهِ يُقَالُ لَهُ مَسْعُودٌ فَقَالَ مَرَّ بِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو بَكْرٍ فَقَالَ لِي أَبُو بَكْرٍ يَا مَسْعُودُ ائْتِ أَبَا تَمِيمٍ - يَعْنِي مَوْلاَهُ - فَقُلْ لَهُ يَحْمِلْنَا عَلَى بَعِيرٍ وَيَبْعَثْ إِلَيْنَا بِزَادٍ وَدَلِيلٍ يَدُلُّنَا ‏.‏ فَجِئْتُ إِلَى مَوْلاَىَ فَأَخْبَرْتُهُ فَبَعَثَ مَعِي بِبَعِيرٍ وَوَطْبٍ مِنْ لَبَنٍ فَجَعَلْتُ آخُذُ بِهِمْ فِي إِخْفَاءِ الطَّرِيقِ وَحَضَرَتِ الصَّلاَةُ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي وَقَامَ أَبُو بَكْرٍ عَنْ يَمِينِهِ وَقَدْ عَرَفْتُ الإِسْلاَمَ وَأَنَا مَعَهُمَا فَجِئْتُ فَقُمْتُ خَلْفَهُمَا فَدَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي صَدْرِ أَبِي بَكْرٍ فَقُمْنَا خَلْفَهُ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ بُرَيْدَةُ هَذَا لَيْسَ بِالْقَوِيِّ فِي الْحَدِيثِ ‏.‏\hadithno{800}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Buraidah bin Sufyin bin Farwah Al-Aslami narrated that a slave of his grandfather who was called Mas'Od said:"The Messenger of Allah (ﷺ) and Abu Bakr passed by me and Abu Bakr said to me: '0 Mas'ud, go to Abu Tamim' - meaning the man from whom he had been freed - 'and tell him to give us a camel so that we could ride, and let him send us some food and a guide to show us the way.' So I went to my former master and told him the same, and he sent with me a camel and vessels of milk, and I brought them via a secret route. Then the time for prayer came and the Messenger of Allah (ﷺ) stood up and prayed, and Abu Bakr stood to his right. I had come to know about Islam and I was with them, so I came and stood behind them. So the Messenger of Allah (ﷺ) pushed Abu Bakr on the chest (to make him move backward) and we stood behind him." Abu 'Abdur-Rahman (An-Nasai)said: (This) Buraidah is not a reliable narrator of Hadith}}
\hadithdefcmd{nasai}{801}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ جَدَّتَهُ، مُلَيْكَةَ دَعَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم لِطَعَامٍ قَدْ صَنَعَتْهُ لَهُ فَأَكَلَ مِنْهُ ثُمَّ قَالَ ‏ "‏ قُومُوا فَلأُصَلِّيَ لَكُمْ ‏"‏ ‏.‏ قَالَ أَنَسٌ فَقُمْتُ إِلَى حَصِيرٍ لَنَا قَدِ اسْوَدَّ مِنْ طُولِ مَا لُبِسَ فَنَضَحْتُهُ بِمَاءٍ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَصَفَفْتُ أَنَا وَالْيَتِيمُ وَرَاءَهُ وَالْعَجُوزُ مِنْ وَرَائِنَا فَصَلَّى لَنَا رَكْعَتَيْنِ ثُمَّ انْصَرَفَ ‏.‏\hadithno{801}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas bin Malik, that his grandmother Mulaikah invited the Messenger of Allah (ﷺ) to come and eat some food that she had prepared for him. Then he said:"Get up and I will lead you in prayer." Anas said: "So I got up and brought a reed mat of ours that had turned black from long use, and spreaded some water on it. The Messenger of Allah (ﷺ) stood and the orphan and I stood in a row behind him, and the old woman stood behind us, and he led us in praying two Rak'ahs, then he left}}
\hadithdefcmd{nasai}{802}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ سُلَيْمَانَ بْنِ الْمُغِيرَةِ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ دَخَلَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَمَا هُوَ إِلاَّ أَنَا وَأُمِّي وَالْيَتِيمُ وَأُمُّ حَرَامٍ خَالَتِي فَقَالَ ‏ "‏ قُومُوا فَلأُصَلِّيَ بِكُمْ ‏"‏ ‏.‏ قَالَ فِي غَيْرِ وَقْتِ صَلاَةٍ - قَالَ - فَصَلَّى بِنَا ‏.‏\hadithno{802}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah (ﷺ) entered upon us and the only people present were myself, my mother, the orphan and Umm Harh, my maternal aunt. He said: 'Stand up and I will lead you in prayer.' It was not the time for a (prescribed) prayer. And he led us in prayer}}
\hadithdefcmd{nasai}{803}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ مُخْتَارٍ، يُحَدِّثُ عَنْ مُوسَى بْنِ أَنَسٍ، عَنْ أَنَسٍ، أَنَّهُ كَانَ هُوَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم وَأُمُّهُ وَخَالَتُهُ فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم فَجَعَلَ أَنَسًا عَنْ يَمِينِهِ وَأُمَّهُ وَخَالَتَهُ خَلْفَهُمَا ‏.‏\hadithno{803}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Anas that he and the Messenger of Allah (ﷺ) and his mother, and his maternal aunt (were together). The Messenger of Allah (ﷺ) prayed, and he told Anas to stand on his right and his mother and maternal aunt behind them}}
\hadithdefcmd{nasai}{804}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي زِيَادٌ، أَنَّ قَزَعَةَ، مَوْلًى لِعَبْدِ قَيْسٍ أَخْبَرَهُ أَنَّهُ، سَمِعَ عِكْرِمَةَ، مَوْلَى ابْنِ عَبَّاسٍ قَالَ قَالَ ابْنُ عَبَّاسٍ صَلَّيْتُ إِلَى جَنْبِ النَّبِيِّ صلى الله عليه وسلم وَعَائِشَةُ خَلْفَنَا تُصَلِّي مَعَنَا وَأَنَا إِلَى جَنْبِ النَّبِيِّ صلى الله عليه وسلم أُصَلِّي مَعَهُ ‏.‏\hadithno{804}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"I prayed beside the Prophet (ﷺ) and Ayesha was behind us praying with us, and I was beside the Prophet (ﷺ) praying with him}}
\hadithdefcmd{nasai}{805}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ اللَّهِ بْنِ الْمُخْتَارِ، عَنْ مُوسَى بْنِ أَنَسٍ، عَنْ أَنَسٍ، قَالَ صَلَّى بِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَبِامْرَأَةٍ مِنْ أَهْلِي فَأَقَامَنِي عَنْ يَمِينِهِ وَالْمَرْأَةُ خَلْفَنَا ‏.‏\hadithno{805}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah (ﷺ) led me and a woman from my family in prayer. He made me to stand on his right and the woman to stand behind us}}
\hadithdefcmd{nasai}{806}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا ابْنُ عُلَيَّةَ، عَنْ أَيُّوبَ، عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدِ بْنِ جُبَيْرٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ بِتُّ عِنْدَ خَالَتِي مَيْمُونَةَ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي مِنَ اللَّيْلِ فَقُمْتُ عَنْ شِمَالِهِ فَقَالَ بِي هَكَذَا فَأَخَذَ بِرَأْسِي فَأَقَامَنِي عَنْ يَمِينِهِ ‏.‏\hadithno{806}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ibn Abbas said:"I stayed overnight with my maternal aunt Maimunah, and the Messenger of Allah (ﷺ) got up to pray at night. I stood on his left, so he did this to me: He took me by the head and made me stand on his right}}
\hadithdefcmd{nasai}{807}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنْ أَبِي مَعْمَرٍ، عَنْ أَبِي مَسْعُودٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَمْسَحُ مَنَاكِبَنَا فِي الصَّلاَةِ وَيَقُولُ ‏ "‏ لاَ تَخْتَلِفُوا فَتَخْتَلِفَ قُلُوبُكُمْ لِيَلِيَنِّي مِنْكُمْ أُولُو الأَحْلاَمِ وَالنُّهَى ثُمَّ الَّذِينَ يَلُونَهُمْ ثُمَّ الَّذِينَ يَلُونَهُمْ ‏"‏ ‏.‏ قَالَ أَبُو مَسْعُودٍ فَأَنْتُمُ الْيَوْمَ أَشَدُّ اخْتِلاَفًا ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ أَبُو مَعْمَرٍ اسْمُهُ عَبْدُ اللَّهِ بْنُ سَخْبَرَةَ ‏.‏\hadithno{807}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Mas'ud Al-Ansiri said:"The Messenger of Allah (ﷺ) used to gently pat our shoulders (to make sure the row was straight) at the time of prayer, and he-would say:'Keep (the rows) straight; do not differ from one another lest your hearts would be afflicted with discord. Let those who are mature and wise stand closest to me, then those who are next to them, then those who are next to them."' Abu Mas'ud said: Today, there is much disharmony among you. ,Abu 'Abdur-Rabin (An-Nasai)said: (One of the narrators) Abu Ma'mar's name is 'Abdullah bin Sakhbarah}}
\hadithdefcmd{nasai}{808}{أَخْبَرَنَا مُحَمَّدُ بْنُ عُمَرَ بْنِ عَلِيِّ بْنِ مُقَدَّمٍ، قَالَ حَدَّثَنَا يُوسُفُ بْنُ يَعْقُوبَ، قَالَ أَخْبَرَنِي التَّيْمِيُّ، عَنْ أَبِي مِجْلَزٍ، عَنْ قَيْسِ بْنِ عَبَّادٍ، قَالَ بَيْنَا أَنَا فِي الْمَسْجِدِ، فِي الصَّفِّ الْمُقَدَّمِ فَجَبَذَنِي رَجُلٌ مِنْ خَلْفِي جَبْذَةً فَنَحَّانِي وَقَامَ مَقَامِي فَوَاللَّهِ مَا عَقَلْتُ صَلاَتِي فَلَمَّا انْصَرَفَ فَإِذَا هُوَ أُبَىُّ بْنُ كَعْبٍ فَقَالَ يَا فَتَى لاَ يَسُؤْكَ اللَّهُ إِنَّ هَذَا عَهْدٌ مِنَ النَّبِيِّ صلى الله عليه وسلم إِلَيْنَا أَنْ نَلِيَهُ ثُمَّ اسْتَقْبَلَ الْقِبْلَةَ فَقَالَ هَلَكَ أَهْلُ الْعُقَدِ وَرَبِّ الْكَعْبَةِ ثَلاَثًا ثُمَّ قَالَ وَاللَّهِ مَا عَلَيْهِمْ آسَى وَلَكِنْ آسَى عَلَى مَنْ أَضَلُّوا ‏.‏ قُلْتُ يَا أَبَا يَعْقُوبَ مَا يَعْنِي بِأَهْلِ الْعُقَدِ قَالَ الأُمَرَاءُ ‏.‏\hadithno{808}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Qais bin 'Ubad said:"While I was in the Masjid in the first row, a man pulled me from behind and moved me aside, and took my place. By Allah, I could not focus on my prayer, then when he left I saw that it was Ubayy bin Ka'b. He said: '0 boy, may Allah protect you from harm. This is what the Prophet instructed us to do, to stand directly behind him.' Then he (Ubayy) turned to face the Qiblah and said: 'Doomed are Ah1 Al-'Uqd, by the Lord of the Ka'bah! - three times.'Then he said: 'By Allah, I am not sad for them, but I am sad for the people whom they have misled.' I said: '0 Abu Ya'qub, what do you mean by Ah1 Al-'Uqd?' He said: 'The rulers}}
\hadithdefcmd{nasai}{809}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ أُقِيمَتِ الصَّلاَةُ فَقُمْنَا فَعُدِّلَتِ الصُّفُوفُ قَبْلَ أَنْ يَخْرُجَ إِلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَتَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى إِذَا قَامَ فِي مُصَلاَّهُ قَبْلَ أَنْ يُكَبِّرَ فَانْصَرَفَ فَقَالَ لَنَا ‏ "‏ مَكَانَكُمْ ‏"‏ ‏.‏ فَلَمْ نَزَلْ قِيَامًا نَنْتَظِرُهُ حَتَّى خَرَجَ إِلَيْنَا قَدِ اغْتَسَلَ يَنْطِفُ رَأْسُهُ مَاءً فَكَبَّرَ وَصَلَّى ‏.‏\hadithno{809}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Salamah bin 'Abdur Rahman narrated that he heard Abu Hurairah say:"The Iqamah for prayer was said, and we stood up and the rows were straightened, before the Messenger of Allah (ﷺ) came out to us. Then the Messenger of Allah (ﷺ) came to us and stood in the place where he prayed, before he said the Takbir he paused and said to us: 'Stay where you are.' So we stayed there, waiting for him, until he came out to us; he had performed Ghusl and his head was dripping with water. Then he said the Takbir and prayed}}
\hadithdefcmd{nasai}{810}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ أَنْبَأَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكٍ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُقَوِّمُ الصُّفُوفَ كَمَا تُقَوَّمُ الْقِدَاحُ فَأَبْصَرَ رَجُلاً خَارِجًا صَدْرُهُ مِنَ الصَّفِّ فَلَقَدْ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَتُقِيمُنَّ صُفُوفَكُمْ أَوْ لَيُخَالِفَنَّ اللَّهُ بَيْنَ وُجُوهِكُمْ ‏"‏ ‏.‏\hadithno{810}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that An-Numan bin Bashir said:"The Messenger of Allah (ﷺ) used to straighten the rows like shaft of an arrow is straightened before the head is attached to it. He saw a man whose chest was sticking out from the row. I saw the Messenger of Allah (ﷺ) say: 'Make your rows straight or Allah will cause your faces to be deformed}}
\hadithdefcmd{nasai}{811}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ مَنْصُورٍ، عَنْ طَلْحَةَ بْنِ مُصَرِّفٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَوْسَجَةَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَخَلَّلُ الصُّفُوفَ مِنْ نَاحِيَةٍ إِلَى نَاحِيَةٍ يَمْسَحُ مَنَاكِبَنَا وَصُدُورَنَا وَيَقُولُ ‏"‏ لاَ تَخْتَلِفُوا فَتَخْتَلِفَ قُلُوبُكُمْ ‏"‏ ‏.‏ وَكَانَ يَقُولُ ‏"‏ إِنَّ اللَّهَ وَمَلاَئِكَتَهُ يُصَلُّونَ عَلَى الصُّفُوفِ الْمُتَقَدِّمَةِ ‏"‏ ‏.‏\hadithno{811}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Al-Bara bin Azib said:"The Messenger of Allah (ﷺ) used to go between the rows from one side to another, patting our shoulders and chests and saying: 'Do not make your rows ragged or your hearts will be filled with enmity toward one another.' And he used to say: 'Allah and His angels send Salah upon the front rows}}
\hadithdefcmd{nasai}{812}{أَخْبَرَنَا بِشْرُ بْنُ خَالِدٍ الْعَسْكَرِيُّ، قَالَ حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنْ أَبِي مَعْمَرٍ، عَنْ أَبِي مَسْعُودٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَمْسَحُ عَوَاتِقَنَا وَيَقُولُ ‏ "‏ اسْتَوُوا وَلاَ تَخْتَلِفُوا فَتَخْتَلِفَ قُلُوبُكُمْ وَلْيَلِيَنِّي مِنْكُمْ أُولُو الأَحْلاَمِ وَالنُّهَى ثُمَّ الَّذِينَ يَلُونَهُمْ ثُمَّ الَّذِينَ يَلُونَهُمْ ‏"‏ ‏.‏\hadithno{812}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Mas'ad Al-Ansari said:"The Messenger of Allah (ﷺ) used to gently pat our shoulders (to make sure the row was straight) at the time of prayer, and he would say: 'Keep (the rows) straight; do not differ from one another lest your hearts should suffer from discord. Let those who are mature and wise stand closest to me, then those who are next to them, then those who are next to them}}
\hadithdefcmd{nasai}{813}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ نَافِعٍ، قَالَ حَدَّثَنَا بَهْزُ بْنُ أَسَدٍ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقُولُ ‏ "‏ اسْتَوُوا اسْتَوُوا اسْتَوُوا فَوَالَّذِي نَفْسِي بِيَدِهِ إِنِّي لأَرَاكُمْ مِنْ خَلْفِي كَمَا أَرَاكُمْ مِنْ بَيْنِ يَدَىَّ ‏"‏ ‏.‏\hadithno{813}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Anas that the Prophet (ﷺ) used to say:"Make your rows straight, make your rows straight, make your rows straight. By the One in Whose Hand is my soul! I can see you behind me as I can see you in front of me}}
\hadithdefcmd{nasai}{814}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، أَنْبَأَنَا إِسْمَاعِيلُ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، - رضى الله عنه - قَالَ أَقْبَلَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِوَجْهِهِ حِينَ قَامَ إِلَى الصَّلاَةِ قَبْلَ أَنْ يُكَبِّرَ فَقَالَ ‏ "‏ أَقِيمُوا صُفُوفَكُمْ وَتَرَاصُّوا فَإِنِّي أَرَاكُمْ مِنْ وَرَاءِ ظَهْرِي ‏"‏ ‏.‏\hadithno{814}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah (ﷺ)turned to face us when he stood up to pray, before he said the Takbir and said: 'Make your rows straight and come close to one another, for I can see you behind my back}}
\hadithdefcmd{nasai}{815}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ الْمُخَرِّمِيُّ، قَالَ حَدَّثَنَا أَبُو هِشَامٍ، قَالَ حَدَّثَنَا أَبَانُ، قَالَ حَدَّثَنَا قَتَادَةُ، قَالَ حَدَّثَنَا أَنَسٌ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ رَاصُّوا صُفُوفَكُمْ وَقَارِبُوا بَيْنَهَا وَحَاذُوا بِالأَعْنَاقِ فَوَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ إِنِّي لأَرَى الشَّيَاطِينَ تَدْخُلُ مِنْ خَلَلِ الصَّفِّ كَأَنَّهَا الْحَذَفُ ‏"‏ ‏.‏\hadithno{815}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Anas narrated that the Prophet (ﷺ) said:"Make your rows solid and close together, and keep your necks in line. By the One in Whose Hand is the soul of Muhammad! I can see the shaitan entering through the gaps in the rows as if they are small sheep}}
\hadithdefcmd{nasai}{816}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا الْفُضَيْلُ بْنُ عِيَاضٍ، عَنِ الأَعْمَشِ، عَنِ الْمُسَيَّبِ بْنِ رَافِعٍ، عَنْ تَمِيمِ بْنِ طَرَفَةَ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ خَرَجَ إِلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ أَلاَ تَصُفُّونَ كَمَا تَصُفُّ الْمَلاَئِكَةُ عِنْدَ رَبِّهِمْ ‏"‏ ‏.‏ قَالُوا وَكَيْفَ تَصُفُّ الْمَلاَئِكَةُ عِنْدَ رَبِّهِمْ قَالَ ‏"‏ يُتِمُّونَ الصَّفَّ الأَوَّلَ ثُمَّ يَتَرَاصُّونَ فِي الصَّفِّ ‏"‏ ‏.‏\hadithno{816}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir bin Samurah said:"The Messenger of Allah (ﷺ) came out to us and said:'Will you not form rows as the angels form rows before their Lord? They said: 'How do the angels form rows before their lord? He said: 'They complete the first row and fill the gaps in the rows}}
\hadithdefcmd{nasai}{817}{أَخْبَرَنِي يَحْيَى بْنُ عُثْمَانَ الْحِمْصِيُّ، قَالَ حَدَّثَنَا بَقِيَّةُ، عَنْ بَحِيرِ بْنِ سَعْدٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، عَنِ الْعِرْبَاضِ بْنِ سَارِيَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي عَلَى الصَّفِّ الأَوَّلِ ثَلاَثًا وَعَلَى الثَّانِي وَاحِدَةً ‏.‏\hadithno{817}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Al'Irbad bin Sariyah that the Messenger of Allah (ﷺ) used to send Salah on the first row three times and on the second row once}}
\hadithdefcmd{nasai}{818}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، عَنْ خَالِدٍ، قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَتِمُّوا الصَّفَّ الأَوَّلَ ثُمَّ الَّذِي يَلِيهِ وَإِنْ كَانَ نَقْصٌ فَلْيَكُنْ فِي الصَّفِّ الْمُؤَخَّرِ ‏"‏ ‏.‏\hadithno{818}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas that the Messenger of Allah (ﷺ) said:"Complete the first row, then the one behind it, and if any row is to be left incomplete let it be the last row}}
\hadithdefcmd{nasai}{819}{أَخْبَرَنَا عِيسَى بْنُ إِبْرَاهِيمَ بْنِ مَثْرُودٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنْ أَبِي الزَّاهِرِيَّةِ، عَنْ كَثِيرِ بْنِ مُرَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ وَصَلَ صَفًّا وَصَلَهُ اللَّهُ وَمَنْ قَطَعَ صَفًّا قَطَعَهُ اللَّهُ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{819}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Abdullih bin 'Umar that the Messenger of Allah (ﷺ)said:"Whoever completes a row, may Allah be generous to him, and whoever cuts a row, may Allah cut him off}}
\hadithdefcmd{nasai}{820}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَيْرُ صُفُوفِ الرِّجَالِ أَوَّلُهَا وَشَرُّهَا آخِرُهَا وَخَيْرُ صُفُوفِ النِّسَاءِ آخِرُهَا وَشَرُّهَا أَوَّلُهَا ‏"‏ ‏.‏\hadithno{820}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'The best rows for men are the front rows and the worst are the last, and the best rows for women are the back rows and the worst are those in the front}}
\hadithdefcmd{nasai}{821}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، عَنْ سُفْيَانَ، عَنْ يَحْيَى بْنِ هَانِئٍ، عَنْ عَبْدِ الْحَمِيدِ بْنِ مَحْمُودٍ، قَالَ كُنَّا مَعَ أَنَسٍ فَصَلَّيْنَا مَعَ أَمِيرٍ مِنَ الأُمَرَاءِ فَدَفَعُونَا حَتَّى قُمْنَا وَصَلَّيْنَا بَيْنَ السَّارِيَتَيْنِ فَجَعَلَ أَنَسٌ يَتَأَخَّرُ وَقَالَ قَدْ كُنَّا نَتَّقِي هَذَا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{821}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Abdul Hamid bin Mahmud said:"We were with Anas and we prayed with one of the Amirs. They pushed us until we stood and prayed between two rows, and Anas started moving backward and said: 'We used to avoid this at the time of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{nasai}{822}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ مِسْعَرٍ، عَنْ ثَابِتِ بْنِ عُبَيْدٍ، عَنِ ابْنِ الْبَرَاءِ، عَنِ الْبَرَاءِ، قَالَ كُنَّا إِذَا صَلَّيْنَا خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم أَحْبَبْتُ أَنْ أَكُونَ عَنْ يَمِينِهِ ‏.‏\hadithno{822}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Al Bara said:"When we prayed behind the Messenger of Allah (ﷺ) I liked to be to his right}}
\hadithdefcmd{nasai}{823}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا صَلَّى أَحَدُكُمْ بِالنَّاسِ فَلْيُخَفِّفْ فَإِنَّ فِيهِمُ السَّقِيمَ وَالضَّعِيفَ وَالْكَبِيرَ فَإِذَا صَلَّى أَحَدُكُمْ لِنَفْسِهِ فَلْيُطَوِّلْ مَا شَاءَ ‏"‏ ‏.‏\hadithno{823}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ)said:"When any one of you leads the people in prayer, let him make it short, for among them are the sick, the weak and the elderly. And when any one of you prays by himself, let him make it as long as he wishes}}
\hadithdefcmd{nasai}{824}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ أَخَفَّ النَّاسِ صَلاَةً فِي تَمَامٍ ‏.‏\hadithno{824}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Anas that the Prophet (ﷺ) used to make his prayer very brief but still complete when leading people}}
\hadithdefcmd{nasai}{825}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، عَنِ الأَوْزَاعِيِّ، قَالَ حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنِّي لأَقُومُ فِي الصَّلاَةِ فَأَسْمَعُ بُكَاءَ الصَّبِيِّ فَأُوجِزُ فِي صَلاَتِي كَرَاهِيَةَ أَنْ أَشُقَّ عَلَى أُمِّهِ ‏"‏ ‏.‏\hadithno{825}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from 'Abdullah bin Abi Qatadah, from his father that the Prophet (ﷺ) said:"I stand in prayer, then I hear a child crying, so I make my prayer brief, because I do not want to cause hardship for his mother}}
\hadithdefcmd{nasai}{826}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، عَنِ ابْنِ أَبِي ذِئْبٍ، قَالَ أَخْبَرَنِي الْحَارِثُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْمُرُ بِالتَّخْفِيفِ وَيَؤُمُّنَا بِالصَّافَّاتِ ‏.‏\hadithno{826}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Abdullah bin 'Umar said:"The Messenger of Allah (ﷺ) used to enjoin upon us to make the prayer short, but he would lead us in prayer and recite As-Saffat}}
\hadithdefcmd{nasai}{827}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عُثْمَانَ بْنِ أَبِي سُلَيْمَانَ، عَنْ عَامِرِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَمْرِو بْنِ سُلَيْمٍ الزُّرَقِيِّ، عَنْ أَبِي قَتَادَةَ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَؤُمُّ النَّاسَ وَهُوَ حَامِلٌ أُمَامَةَ بِنْتَ أَبِي الْعَاصِ عَلَى عَاتِقِهِ فَإِذَا رَكَعَ وَضَعَهَا وَإِذَا رَفَعَ مِنْ سُجُودِهِ أَعَادَهَا ‏.‏\hadithno{827}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Qatadah said:"I saw the Messenger of Allah (ﷺ)leading the people in prayer, carrying Umamah bint Abi Al-As on his shoulder. When he bowed he put her down and when he stood up from prostration he picked her up again}}
\hadithdefcmd{nasai}{828}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ مُحَمَّدٌ صلى الله عليه وسلم ‏ "‏ أَلاَ يَخْشَى الَّذِي يَرْفَعُ رَأْسَهُ قَبْلَ الإِمَامِ أَنْ يُحَوِّلَ اللَّهُ رَأْسَهُ رَأْسَ حِمَارٍ ‏"‏ ‏.‏\hadithno{828}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"Muhammad (ﷺ) said: 'Does the one who raises his head before the Imam not fear that Allah may turn his head into the head of a donkey?}}
\hadithdefcmd{nasai}{829}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا ابْنُ عُلَيَّةَ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ يَزِيدَ، يَخْطُبُ قَالَ حَدَّثَنَا الْبَرَاءُ، وَكَانَ، غَيْرَ كَذُوبٍ أَنَّهُمْ كَانُوا إِذَا صَلَّوْا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَرَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ قَامُوا قِيَامًا حَتَّى يَرَوْهُ سَاجِدًا ثُمَّ سَجَدُوا ‏.‏\hadithno{829}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Ishaq said:"I heard 'Abdullah bin Yazid delivering a Khutbah. He said: 'Al-Bara, who was no liar,told us that when they prayed with the Messenger of Allah (ﷺ) would raise his head from bowing and they would remain standing until they saw him prostrate, then they would prostrate}}
\hadithdefcmd{nasai}{830}{أَخْبَرَنَا مُؤَمَّلُ بْنُ هِشَامٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ يُونُسَ بْنِ جُبَيْرٍ، عَنْ حِطَّانَ بْنِ عَبْدِ اللَّهِ، قَالَ صَلَّى بِنَا أَبُو مُوسَى فَلَمَّا كَانَ فِي الْقَعْدَةِ دَخَلَ رَجُلٌ مِنَ الْقَوْمِ فَقَالَ أُقِرَّتِ الصَّلاَةُ بِالْبِرِّ وَالزَّكَاةِ ‏.‏ فَلَمَّا سَلَّمَ أَبُو مُوسَى أَقْبَلَ عَلَى الْقَوْمِ فَقَالَ أَيُّكُمُ الْقَائِلُ هَذِهِ الْكَلِمَةَ فَأَرَمَّ الْقَوْمُ ‏.‏ قَالَ يَا حِطَّانُ لَعَلَّكَ قُلْتَهَا قَالَ لاَ وَقَدْ خَشِيتُ أَنْ تَبْكَعَنِي بِهَا فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُعَلِّمُنَا صَلاَتَنَا وَسُنَّتَنَا فَقَالَ ‏"‏ إِنَّمَا الإِمَامُ لِيُؤْتَمَّ بِهِ فَإِذَا كَبَّرَ فَكَبِّرُوا وَإِذَا قَالَ ‏\{‏ غَيْرِ الْمَغْضُوبِ عَلَيْهِمْ وَلاَ الضَّالِّينَ ‏\}‏ فَقُولُوا آمِينَ يُجِبْكُمُ اللَّهُ وَإِذَا رَكَعَ فَارْكَعُوا وَإِذَا رَفَعَ فَقَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ فَقُولُوا رَبَّنَا لَكَ الْحَمْدُ يَسْمَعِ اللَّهُ لَكُمْ وَإِذَا سَجَدَ فَاسْجُدُوا وَإِذَا رَفَعَ فَارْفَعُوا فَإِنَّ الإِمَامَ يَسْجُدُ قَبْلَكُمْ وَيَرْفَعُ قَبْلَكُمْ ‏"‏ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَتِلْكَ بِتِلْكَ ‏"‏ ‏.‏\hadithno{830}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Hittan bin 'Abdullah said:"Abu Musa led us in prayer and when he was sitting, a man from among the people entered and said: 'Prayer is based on righteousness and is always mentioned alongside Zakah (in the Qur'an).' When Abu Musa had said the Salam, he turned to the people and said: 'Which of you spoke these words?' The people kept quiet. Then he said: 'O Hittan, perhaps you said it?' He said: 'No, but I was afraid that you would rebuke me for it.' He said: 'The Messenger of Allah (ﷺ) taught us our prayer and Sunnah prayers, and he said: The Imam is appointed to be followed, so when he says the Takbir, say the Takbir; when he says "Not (the way) of those who earned Your Anger, nor of those who went astray," say Amin, and Allah will respond to you; when he rises up from bowing and says, 'Sami' Allalhu liman hamidah (Allah hears those who praise Him), say 'Rabbana lakal-hamd (Our Lord, to You be praise),' and Allah will hear you; when he prostrates, prostrate, and when he sits up, sit up. The Imam should prostrate before you do and sit up before you do.' The Messenger of Allah (ﷺ) said: 'This makes up for that}}
\hadithdefcmd{nasai}{831}{أَخْبَرَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنِ الأَعْمَشِ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، وَأَبِي، صَالِحٍ عَنْ جَابِرٍ، قَالَ جَاءَ رَجُلٌ مِنَ الأَنْصَارِ وَقَدْ أُقِيمَتِ الصَّلاَةُ فَدَخَلَ الْمَسْجِدَ فَصَلَّى خَلْفَ مُعَاذٍ فَطَوَّلَ بِهِمْ فَانْصَرَفَ الرَّجُلُ فَصَلَّى فِي نَاحِيَةِ الْمَسْجِدِ ثُمَّ انْطَلَقَ فَلَمَّا قَضَى مُعَاذٌ الصَّلاَةَ قِيلَ لَهُ إِنَّ فُلاَنًا فَعَلَ كَذَا وَكَذَا ‏.‏ فَقَالَ مُعَاذٌ لَئِنْ أَصْبَحْتُ لأَذْكُرَنَّ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَأَتَى مُعَاذٌ النَّبِيَّ صلى الله عليه وسلم فَذَكَرَ ذَلِكَ لَهُ فَأَرْسَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَيْهِ فَقَالَ ‏"‏ مَا حَمَلَكَ عَلَى الَّذِي صَنَعْتَ ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ عَمِلْتُ عَلَى نَاضِحِي مِنَ النَّهَارِ فَجِئْتُ وَقَدْ أُقِيمَتِ الصَّلاَةُ فَدَخَلْتُ الْمَسْجِدَ فَدَخَلْتُ مَعَهُ فِي الصَّلاَةِ فَقَرَأَ سُورَةَ كَذَا وَكَذَا فَطَوَّلَ فَانْصَرَفْتُ فَصَلَّيْتُ فِي نَاحِيَةِ الْمَسْجِدِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَفَتَّانٌ يَا مُعَاذُ أَفَتَّانٌ يَا مُعَاذُ أَفَتَّانٌ يَا مُعَاذُ ‏"‏ ‏.‏\hadithno{831}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Jabir said:"A man from the Ansar came when the Iqamah for prayer had been said. He entered the Masjid and prayed behind Muadh, and he(Muadh) made the prayer lengthy. The man went away and prayed in a comer of the Masjid, then he left. When Muadh finished praying, it was said to him that so-and-so had done such and such. Muadh said: 'Tomorrow I will mention that to the Messenger of Allah (ﷺ).' So Muadh came to the Messenger of Allah (ﷺ) and told him about that. The Messenger of Allah (ﷺ) sent for him and asked him: 'What made you do what you did? He said: '0 Messenger of Allah (ﷺ), I had been working with my camel to bring water all day, and when I came the Iqamah for prayer had already been said, so I entered the Masjid and joined him in the prayer, then he recited such and such a Surah and made it lengthy, so I went away and prayed in a comer of the Masjid.' The Messenger of Allah (ﷺ) said: 'Do you want to cause hardship to the people, 0 Muadh do you want to cause hardship to the people, 0 Muadh do you want to cause hardship to the people, 0 Muadh?}}
\hadithdefcmd{nasai}{832}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَكِبَ فَرَسًا فَصُرِعَ عَنْهُ فَجُحِشَ شِقُّهُ الأَيْمَنُ فَصَلَّى صَلاَةً مِنَ الصَّلَوَاتِ وَهُوَ قَاعِدٌ فَصَلَّيْنَا وَرَاءَهُ قُعُودًا فَلَمَّا انْصَرَفَ قَالَ ‏ "‏ إِنَّمَا جُعِلَ الإِمَامُ لِيُؤْتَمَّ بِهِ فَإِذَا صَلَّى قَائِمًا فَصَلُّوا قِيَامًا وَإِذَا رَكَعَ فَارْكَعُوا وَإِذَا قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ فَقُولُوا رَبَّنَا لَكَ الْحَمْدُ وَإِذَا صَلَّى جَالِسًا فَصَلُّوا جُلُوسًا أَجْمَعُونَ ‏"‏ ‏.‏\hadithno{832}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) rode a horse and fell from it, and sustained an injury on his right side. He led one of the prayers sitting, and we prayed behind him sitting. When he had finished he said:"The Imam is appointed to be followed. If he prays standing then pray standing; when he bows, bow; when he says, Sami' Allahu liman hamidah (Allah hears those who praise Him), say 'Rabbana lakalhamd (Our Lord, to You be praise); and if he prays sitting then pray sitting, all of you}}
\hadithdefcmd{nasai}{833}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا ثَقُلَ رَسُولُ اللَّهِ صلى الله عليه وسلم جَاءَ بِلاَلٌ يُؤْذِنُهُ بِالصَّلاَةِ فَقَالَ ‏"‏ مُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ بِالنَّاسِ ‏"‏ ‏.‏ قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ أَبَا بَكْرٍ رَجُلٌ أَسِيفٌ وَإِنَّهُ مَتَى يَقُومُ فِي مَقَامِكَ لاَ يُسْمِعُ النَّاسَ فَلَوْ أَمَرْتَ عُمَرَ ‏.‏ فَقَالَ ‏"‏ مُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ بِالنَّاسِ ‏"‏ ‏.‏ فَقُلْتُ لِحَفْصَةَ قُولِي لَهُ فَقَالَتْ لَهُ ‏.‏ فَقَالَ ‏"‏ إِنَّكُنَّ لأَنْتُنَّ صَوَاحِبَاتُ يُوسُفَ مُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ بِالنَّاسِ ‏"‏ ‏.‏ قَالَتْ فَأَمَرُوا أَبَا بَكْرٍ فَلَمَّا دَخَلَ فِي الصَّلاَةِ وَجَدَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ نَفْسِهِ خِفَّةً - قَالَتْ - فَقَامَ يُهَادَى بَيْنَ رَجُلَيْنِ وَرِجْلاَهُ تَخُطَّانِ فِي الأَرْضِ فَلَمَّا دَخَلَ الْمَسْجِدَ سَمِعَ أَبُو بَكْرٍ حِسَّهُ فَذَهَبَ لِيَتَأَخَّرَ فَأَوْمَأَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ قُمْ كَمَا أَنْتَ قَالَتْ فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى قَامَ عَنْ يَسَارِ أَبِي بَكْرٍ جَالِسًا فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي بِالنَّاسِ جَالِسًا وَأَبُو بَكْرٍ قَائِمًا يَقْتَدِي أَبُو بَكْرٍ بِرَسُولِ اللَّهِ صلى الله عليه وسلم وَالنَّاسُ يَقْتَدُونَ بِصَلاَةِ أَبِي بَكْرٍ رضى الله عنه ‏.‏\hadithno{833}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Aisha said:"When the Messenger of Allah (ﷺ) became seriously ill, Bilal came to tell him it was time to pray and he said: 'Tell Abu Bakr to lead the people in prayer."' She said: "I said: '0 Messenger of Allah (ﷺ), Abu Bakr is a tender-hearted man, and when he stands in your place he will not be able to make the people hear his voice; why don't you tell 'Umar (to do it)?' He said: 'Tell a Abu Bakr to lead the people in the prayer.' I said to Hafsah: 'Tell him.' So she told him. He said: 'You are (like) the female companions of Yosuf. Tell Abu Bakr lead the people in prayer."' She said: "So they told Abu Bakr. When he started to pray, the Messenger of Allah (ﷺ) began to feel better, so he got up and came with the help of two men, with his feet dragging along the ground. (When) he entered the Masjid, Abu Bakr heard him coming and he wanted to step back, but the Messenger of Allah (ﷺ) gestured to him: 'Stay where you are.' Then the Messenger of Allah (ﷺ) came and sat on Abu Bakr's left, so the Messenger of Allah (ﷺ) was leading the people in prayer sitting, and Abu Bakr was standing and following the Messenger of Allah (ﷺ) and the people were following the prayer of Abu Bakr, may Allah be pleased with him}}
\hadithdefcmd{nasai}{834}{أَخْبَرَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالَ حَدَّثَنَا زَائِدَةُ، عَنْ مُوسَى بْنِ أَبِي عَائِشَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، قَالَ دَخَلْتُ عَلَى عَائِشَةَ فَقُلْتُ أَلاَ تُحَدِّثِينِي عَنْ مَرَضِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَتْ لَمَّا ثَقُلَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ أَصَلَّى النَّاسُ ‏"‏ ‏.‏ فَقُلْنَا لاَ وَهُمْ يَنْتَظِرُونَكَ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ ‏"‏ ضَعُوا لِي مَاءً فِي الْمِخْضَبِ ‏"‏ ‏.‏ فَفَعَلْنَا فَاغْتَسَلَ ثُمَّ ذَهَبَ لِيَنُوءَ فَأُغْمِيَ عَلَيْهِ ثُمَّ أَفَاقَ فَقَالَ ‏"‏ أَصَلَّى النَّاسُ ‏"‏ ‏.‏ قُلْنَا لاَ هُمْ يَنْتَظِرُونَكَ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ ‏"‏ ضَعُوا لِي مَاءً فِي الْمِخْضَبِ ‏"‏ ‏.‏ فَفَعَلْنَا فَاغْتَسَلَ ثُمَّ ذَهَبَ لِيَنُوءَ ثُمَّ أُغْمِيَ عَلَيْهِ ثُمَّ قَالَ فِي الثَّالِثَةِ مِثْلَ قَوْلِهِ قَالَتْ وَالنَّاسُ عُكُوفٌ فِي الْمَسْجِدِ يَنْتَظِرُونَ رَسُولَ اللَّهِ صلى الله عليه وسلم لِصَلاَةِ الْعِشَاءِ فَأَرْسَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى أَبِي بَكْرٍ ‏"‏ أَنْ صَلِّ بِالنَّاسِ ‏"‏ ‏.‏ فَجَاءَهُ الرَّسُولُ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم يَأْمُرُكَ أَنْ تُصَلِّيَ بِالنَّاسِ وَكَانَ أَبُو بَكْرٍ رَجُلاً رَقِيقًا فَقَالَ يَا عُمَرُ صَلِّ بِالنَّاسِ ‏.‏ فَقَالَ أَنْتَ أَحَقُّ بِذَلِكَ ‏.‏ فَصَلَّى بِهِمْ أَبُو بَكْرٍ تِلْكَ الأَيَّامَ ثُمَّ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم وَجَدَ مِنْ نَفْسِهِ خِفَّةً فَجَاءَ يُهَادَى بَيْنَ رَجُلَيْنِ أَحَدُهُمَا الْعَبَّاسُ لِصَلاَةِ الظُّهْرِ فَلَمَّا رَآهُ أَبُو بَكْرٍ ذَهَبَ لِيَتَأَخَّرَ فَأَوْمَأَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ لاَ يَتَأَخَّرَ وَأَمَرَهُمَا فَأَجْلَسَاهُ إِلَى جَنْبِهِ فَجَعَلَ أَبُو بَكْرٍ يُصَلِّي قَائِمًا وَالنَّاسُ يُصَلُّونَ بِصَلاَةِ أَبِي بَكْرٍ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي قَاعِدًا ‏.‏ فَدَخَلْتُ عَلَى ابْنِ عَبَّاسٍ فَقُلْتُ أَلاَ أَعْرِضُ عَلَيْكَ مَا حَدَّثَتْنِي عَائِشَةُ عَنْ مَرَضِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ نَعَمْ ‏.‏ فَحَدَّثْتُهُ فَمَا أَنْكَرَ مِنْهُ شَيْئًا غَيْرَ أَنَّهُ قَالَ أَسَمَّتْ لَكَ الرَّجُلَ الَّذِي كَانَ مَعَ الْعَبَّاسِ قُلْتُ لاَ ‏.‏ قَالَ هُوَ عَلِيٌّ كَرَّمَ اللَّهُ وَجْهَهُ ‏.‏\hadithno{834}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Ubaidullah bin 'Abdullah said:"I entered upon Aisha and said: 'Will you not tell me about the sickness of the Messenger of Allah (ﷺ)?' She said: 'When the Messenger of Allah (ﷺ), became seriously ill, he said: "Have the people prayed?" We said: "No, they are waiting for you, 0 Messenger of Allah (ﷺ)" He said: "Put some water in a tub for me." We did that and he performed Ghusl, then he tried to get up but he fainted. Then he came to us and said: "Have the people prayed?" We said: "No, they are waiting for you, 0 Messenger of Allah (ﷺ)." He said: "Put some water in a tub for me." We did that and he performed Ghusl, then he tried to get up but he fainted. Then for the third time he said the same thing. She said: The people were in the Masjid, waiting for the Messenger of Allah (ﷺ) to lead the prayer. The Messenger of Allah (ﷺ) sent word to Abu Bakr, telling him to lead the people in prayer, so the messenger came to him and said: "The Messenger of Allah (ﷺ) is telling you to lead the people in prayer." Abu Bakr was a tenderhearted man, he said: "0 'Umar. lead the in prayer." But ('Umar) said: "You have more right to that." So Abu Bakr led them in prayer during those days. When the Messenger of Allah (ﷺ) felt a little better, he came with the help of two men, one of whom was Al-'Abbas, to pray Zuhr. When Abu Bakr saw him, he wanted to step back, but the Messenger of Allah (ﷺ) gestured to him not to step back. He told them (the two men) to seat him beside Abu Bakr, and Abu Bakr started to pray standing. The people were following the prayer of Abu Bakr and the Messenger of Allah (ﷺ) was praying sitting."' "I ('Ubaidullah) entered upon Ibn Abbas and said 'Shall I not tell you what Aisha narrated to me about the sickness of the Messenger of Allah (ﷺ)?' He said: 'Yes.' So I told him and he did not deny any of it, but he said: 'Did she tell you the name of the man who was with Al-'Abbas?' I said: 'No.' He said: 'That was Ali, may Allah honor his face}}
\hadithdefcmd{nasai}{835}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ كَانَ مُعَاذٌ يُصَلِّي مَعَ النَّبِيِّ صلى الله عليه وسلم ثُمَّ يَرْجِعُ إِلَى قَوْمِهِ يَؤُمُّهُمْ فَأَخَّرَ ذَاتَ لَيْلَةٍ الصَّلاَةَ وَصَلَّى مَعَ النَّبِيِّ صلى الله عليه وسلم ثُمَّ رَجَعَ إِلَى قَوْمِهِ يَؤُمُّهُمْ فَقَرَأَ سُورَةَ الْبَقَرَةِ فَلَمَّا سَمِعَ رَجُلٌ مِنَ الْقَوْمِ تَأَخَّرَ فَصَلَّى ثُمَّ خَرَجَ فَقَالُوا نَافَقْتَ يَا فُلاَنُ ‏.‏ فَقَالَ وَاللَّهِ مَا نَافَقْتُ وَلآتِيَنَّ النَّبِيَّ صلى الله عليه وسلم فَأُخْبِرُهُ ‏.‏ فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ مُعَاذًا يُصَلِّي مَعَكَ ثُمَّ يَأْتِينَا فَيَؤُمُّنَا وَإِنَّكَ أَخَّرْتَ الصَّلاَةَ الْبَارِحَةَ فَصَلَّى مَعَكَ ثُمَّ رَجَعَ فَأَمَّنَا فَاسْتَفْتَحَ بِسُورَةِ الْبَقَرَةِ فَلَمَّا سَمِعْتُ ذَلِكَ تَأَخَّرْتُ فَصَلَّيْتُ وَإِنَّمَا نَحْنُ أَصْحَابُ نَوَاضِحَ نَعْمَلُ بِأَيْدِينَا ‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يَا مُعَاذُ أَفَتَّانٌ أَنْتَ اقْرَأْ بِسُورَةِ كَذَا وَسُورَةِ كَذَا ‏"‏ ‏.‏\hadithno{835}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Amr said:"I heard Jabir bin 'Abdullah say: 'Mu'adh used to pray with the Prophet (ﷺ) then he would go back to his people to lead them in a prayer. He stayed late one night and prayed with the Prophet (ﷺ) then he went back to his people to lead them in prayer, and he recited Surat Al-Baqarah. When a man from his people heard that, he stepped aside and prayed (on his own), then he left. They said: 'You have become a hypocrite, 0 so and-so!' He said: 'By Allah, I have not become a hypocrite, and I will go to the Prophet (ﷺ) and tell him (about that),' So he went to the Prophet and said: '0 Messenger of Allah(ﷺ), Muadh prays with you, then he comes to lead us in prayer. You delayed the prayer, and he prayed with you then he came back to lead us in prayer, and he started to recite Shut Al-Baqarah. When I heard that, I stepped aside and prayed by myself, because we are people who bring water with the camels and we work hard.' The Prophet (ﷺ) said to him: '0 Muadh, do you want to cause hardship to the people? Recite such and such a Surah, and such and such a Surah}}
\hadithdefcmd{nasai}{836}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ أَشْعَثَ، عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ صَلَّى صَلاَةَ الْخَوْفِ فَصَلَّى بِالَّذِينَ خَلْفَهُ رَكْعَتَيْنِ وَبِالَّذِينَ جَاءُوا رَكْعَتَيْنِ فَكَانَتْ لِلنَّبِيِّ صلى الله عليه وسلم أَرْبَعًا وَلِهَؤُلاَءِ رَكْعَتَيْنِ رَكْعَتَيْنِ ‏.‏\hadithno{836}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih  Witness Sahih Muslim (843/ 312)}\hadithtrans{It was narrated from Abu Bakr that the Prophet (ﷺ) offered the fear prayer (Salat Al-Khauf). He led those who were behind him in two Rak'ah and those who came (after them) in two Rak'ah, so the Prophet (ﷺ) prayed four Rak'ahs and each group prayed two}}
\hadithdefcmd{nasai}{837}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ صَلاَةُ الْجَمَاعَةِ تَفْضُلُ عَلَى صَلاَةِ الْفَذِّ بِسَبْعٍ وَعِشْرِينَ دَرَجَةً ‏"‏ ‏.‏\hadithno{837}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah (ﷺ) said:"Praying in congregation is twenty-seven times better than praying alone}}
\hadithdefcmd{nasai}{838}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ صَلاَةُ الْجَمَاعَةِ أَفْضَلُ مِنْ صَلاَةِ أَحَدِكُمْ وَحْدَهُ خَمْسًا وَعِشْرِينَ جُزْءًا ‏"‏ ‏.‏\hadithno{838}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"Praying in congregation is twenty-five portions better than one of you praying alone}}
\hadithdefcmd{nasai}{839}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَمَّارٍ، قَالَ حَدَّثَنِي الْقَاسِمُ بْنُ مُحَمَّدٍ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ صَلاَةُ الْجَمَاعَةِ تَزِيدُ عَلَى صَلاَةِ الْفَذِّ خَمْسًا وَعِشْرِينَ دَرَجَةً ‏"‏ ‏.‏\hadithno{839}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from that the Prophet (ﷺ) said:"Prayer in congregation is twenty-five levels better than a prayer offered on one's own}}
\hadithdefcmd{nasai}{840}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا كَانُوا ثَلاَثَةً فَلْيَؤُمَّهُمْ أَحَدُهُمْ وَأَحَقُّهُمْ بِالإِمَامَةِ أَقْرَؤُهُمْ ‏"‏ ‏.‏\hadithno{840}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Sa'eed said:"The Messenger of Allah (ﷺ)said: 'If there are three people, let one of them lead the others in prayer, and the one who has the most right to lead the prayer is the one who recites (knows) the most (Qur'an)}}
\hadithdefcmd{nasai}{841}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي زِيَادٌ، أَنَّ قَزَعَةَ، مَوْلًى لِعَبْدِ الْقَيْسِ أَخْبَرَهُ أَنَّهُ، سَمِعَ عِكْرِمَةَ، قَالَ قَالَ ابْنُ عَبَّاسٍ صَلَّيْتُ إِلَى جَنْبِ النَّبِيِّ صلى الله عليه وسلم وَعَائِشَةُ خَلْفَنَا تُصَلِّي مَعَنَا وَأَنَا إِلَى جَنْبِ النَّبِيِّ صلى الله عليه وسلم أُصَلِّي مَعَهُ ‏.‏\hadithno{841}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn 'Abbas said:"I prayed beside the Prophet (ﷺ) and Aisha was behind us praying with us, and I was beside the Prophet (ﷺ) praying with him}}
\hadithdefcmd{nasai}{842}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي سُلَيْمَانَ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ صَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُمْتُ عَنْ يَسَارِهِ فَأَخَذَنِي بِيَدِهِ الْيُسْرَى فَأَقَامَنِي عَنْ يَمِينِهِ ‏.‏\hadithno{842}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn Abbas said:"I prayed with the Messenger of Allah (ﷺ)and I stood on his left. He took hold of me with his left hand and made me stand on his right}}
\hadithdefcmd{nasai}{843}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، عَنْ شُعْبَةَ، عَنْ أَبِي إِسْحَاقَ، أَنَّهُ أَخْبَرَهُمْ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَصِيرٍ، عَنْ أَبِيهِ، - قَالَ شُعْبَةُ وَقَالَ أَبُو إِسْحَاقَ وَقَدْ سَمِعْتُهُ مِنْهُ، وَمِنْ أَبِيهِ - قَالَ سَمِعْتُ أُبَىَّ بْنَ كَعْبٍ، يَقُولُ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمًا صَلاَةَ الصُّبْحِ فَقَالَ ‏"‏ أَشَهِدَ فُلاَنٌ الصَّلاَةَ ‏"‏ ‏.‏ قَالُوا لاَ ‏.‏ قَالَ ‏"‏ فَفُلاَنٌ ‏"‏ ‏.‏ قَالُوا لاَ ‏.‏ قَالَ ‏"‏ إِنَّ هَاتَيْنِ الصَّلاَتَيْنِ مِنْ أَثْقَلِ الصَّلاَةِ عَلَى الْمُنَافِقِينَ وَلَوْ يَعْلَمُونَ مَا فِيهِمَا لأَتَوْهُمَا وَلَوْ حَبْوًا وَالصَّفُّ الأَوَّلُ عَلَى مِثْلِ صَفِّ الْمَلاَئِكَةِ وَلَوْ تَعْلَمُونَ فَضِيلَتَهُ لاَبْتَدَرْتُمُوهُ وَصَلاَةُ الرَّجُلِ مَعَ الرَّجُلِ أَزْكَى مِنْ صَلاَتِهِ وَحْدَهُ وَصَلاَةُ الرَّجُلِ مَعَ الرَّجُلَيْنِ أَزْكَى مِنْ صَلاَتِهِ مَعَ الرَّجُلِ وَمَا كَانُوا أَكْثَرَ فَهُوَ أَحَبُّ إِلَى اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{843}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ubay bin Ka'b said:"One day the Messenger of Allah (ﷺ) prayed Fajr, then he said: 'Did so-and-so attend the prayer? They said: 'No.' He said: '(What about) so-and-so? They said:'No' He said: 'These two prayers. are the most burdensome for the hypocrites. If they knew what (virtue) there is in them, they would come, even if they had to crawl. And the virtue of the first row is like that of the row of the angels. If you knew its virtue, you would compete for it. A man's prayer with another man is greater in reward than his prayer alone. And a man's prayer with two other men is greater in reward than his prayer with one other man; the more people there are, the more beloved that is to Allah, the Mighty and Sublime}}
\hadithdefcmd{nasai}{844}{أَخْبَرَنَا نَصْرُ بْنُ عَلِيٍّ، قَالَ أَنْبَأَنَا عَبْدُ الأَعْلَى، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ مَحْمُودٍ، عَنْ عِتْبَانَ بْنِ مَالِكٍ، أَنَّهُ قَالَ يَا رَسُولَ اللَّهِ إِنَّ السُّيُولَ لَتَحُولُ بَيْنِي وَبَيْنَ مَسْجِدِ قَوْمِي فَأُحِبُّ أَنْ تَأْتِيَنِي فَتُصَلِّيَ فِي مَكَانٍ مِنْ بَيْتِي أَتَّخِذُهُ مَسْجِدًا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ سَنَفْعَلُ ‏"‏ ‏.‏ فَلَمَّا دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ أَيْنَ تُرِيدُ ‏"‏ ‏.‏ فَأَشَرْتُ إِلَى نَاحِيَةٍ مِنَ الْبَيْتِ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَفَفْنَا خَلْفَهُ فَصَلَّى بِنَا رَكْعَتَيْنِ ‏.‏\hadithno{844}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Itban bin Malik that he said:"0 Messenger of Allah (ﷺ) the floods keep me from coming to the Masjid of my people. I would like you to come and pray in a place in my house so that I can take it as a Masjid." The Messenger of Allah (ﷺ) said: "We shall do that." "When the Messenger of Allah (ﷺ) entered he said: 'Where do you want (me to pray).' I showed him a comer of the house, and the Messenger of Allah (ﷺ) stood there, and we formed rows behind him, and he led us in praying two Rak'ahs}}
\hadithdefcmd{nasai}{845}{أَنْبَأَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ أَقْبَلَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِوَجْهِهِ حِينَ قَامَ إِلَى الصَّلاَةِ قَبْلَ أَنْ يُكَبِّرَ فَقَالَ ‏ "‏ أَقِيمُوا صُفُوفَكُمْ وَتَرَاصُّوا فَإِنِّي أَرَاكُمْ مِنْ وَرَاءِ ظَهْرِي ‏"‏ ‏.‏\hadithno{845}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah (ﷺ) turned to face us when he stood up to pray, before he said Takbir, and said: 'Make your rows straight and fill the gaps, for I can see you from behind my back}}
\hadithdefcmd{nasai}{846}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، قَالَ حَدَّثَنَا أَبُو زُبَيْدٍ، - وَاسْمُهُ عَبْثَرُ بْنُ الْقَاسِمِ - عَنْ حُصَيْنٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ قَالَ بَعْضُ الْقَوْمِ لَوْ عَرَّسْتَ بِنَا يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ إِنِّي أَخَافُ أَنْ تَنَامُوا عَنِ الصَّلاَةِ ‏"‏ ‏.‏ قَالَ بِلاَلٌ أَنَا أَحْفَظُكُمْ ‏.‏ فَاضْطَجَعُوا فَنَامُوا وَأَسْنَدَ بِلاَلٌ ظَهْرَهُ إِلَى رَاحِلَتِهِ فَاسْتَيْقَظَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَدْ طَلَعَ حَاجِبُ الشَّمْسِ فَقَالَ ‏"‏ يَا بِلاَلُ أَيْنَ مَا قُلْتَ ‏"‏ ‏.‏ قَالَ مَا أُلْقِيَتْ عَلَىَّ نَوْمَةٌ مِثْلُهَا قَطُّ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ قَبَضَ أَرْوَاحَكُمْ حِينَ شَاءَ فَرَدَّهَا حِينَ شَاءَ قُمْ يَا بِلاَلُ فَآذِنِ النَّاسَ بِالصَّلاَةِ ‏"‏ ‏.‏ فَقَامَ بِلاَلٌ فَأَذَّنَ فَتَوَضَّئُوا - يَعْنِي حِينَ ارْتَفَعَتِ الشَّمْسُ - ثُمَّ قَامَ فَصَلَّى بِهِمْ ‏.‏\hadithno{846}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Abdullah bin Abi Qatadah that his father said:"We were with the Messenger of Allah (ﷺ) when some of the people said: 'Why do you not stop with us to rest awhile, 0 Messenger of Allah (ﷺ)?' He said: 'I am afraid that you will sleep and miss the prayer.' Bilal said:'I will wake you up.' So they lay down and slept, and Bilal leaned back on his mount. Then the Messenger of Allah (ﷺ) woke up when the sun had already started to rise, and he said: '0 Bilal, what about what you told us?' He said: 'I have never slept like that before.' The Messenger of Allah (ﷺ) said: 'Allah, the Mighty and Sublime, takes your souls when He wills and sends them back when He wills.' Stand up 0 Bilal and call the people to prayer.' Then Bilal stood up and \& called the Adhan, and they performed Wudu' - that is, when the sun had risen (fully) - "then he stood and lead them in prayer}}
\hadithdefcmd{nasai}{847}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ زَائِدَةَ بْنِ قُدَامَةَ، قَالَ حَدَّثَنَا السَّائِبُ بْنُ حُبَيْشٍ الْكَلاَعِيُّ، عَنْ مَعْدَانَ بْنِ أَبِي طَلْحَةَ الْيَعْمَرِيِّ، قَالَ قَالَ لِي أَبُو الدَّرْدَاءِ أَيْنَ مَسْكَنُكَ قُلْتُ فِي قَرْيَةٍ دُوَيْنَ حِمْصَ ‏.‏ فَقَالَ أَبُو الدَّرْدَاءِ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مِنْ ثَلاَثَةٍ فِي قَرْيَةٍ وَلاَ بَدْوٍ لاَ تُقَامُ فِيهِمُ الصَّلاَةُ إِلاَّ قَدِ اسْتَحْوَذَ عَلَيْهِمُ الشَّيْطَانُ فَعَلَيْكُمْ بِالْجَمَاعَةِ فَإِنَّمَا يَأْكُلُ الذِّئْبُ الْقَاصِيَةَ ‏"‏ ‏.‏ قَالَ السَّائِبُ يَعْنِي بِالْجَمَاعَةِ الْجَمَاعَةَ فِي الصَّلاَةِ ‏.‏\hadithno{847}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ma'din bin Abi Talhah Al-Ya'muri said:"Abu Ad-Darda said to me: 'Where do you live?' I said: 'In a town near Hims.' Abu Ad-Darda said: 'I heard the Messenger of Allah (ﷺ) say: "There are no three people in a town or encampment among whom prayer is not established, but the Shaitan takes control of them. Therefore, stick to the congregation, for the wolf eats the sheep that strays off on its own." (One of the narrators (As Sa'ib) said: "The congregation means the congregational prayer}}
\hadithdefcmd{nasai}{848}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لَقَدْ هَمَمْتُ أَنْ آمُرَ بِحَطَبٍ فَيُحْطَبَ ثُمَّ آمُرَ بِالصَّلاَةِ فَيُؤَذَّنَ لَهَا ثُمَّ آمُرَ رَجُلاً فَيَؤُمَّ النَّاسَ ثُمَّ أُخَالِفَ إِلَى رِجَالٍ فَأُحَرِّقَ عَلَيْهِمْ بُيُوتَهُمْ وَالَّذِي نَفْسِي بِيَدِهِ لَوْ يَعْلَمُ أَحَدُهُمْ أَنَّهُ يَجِدُ عَظْمًا سَمِينًا أَوْ مَرْمَاتَيْنِ حَسْنَتَيْنِ لَشَهِدَ الْعِشَاءَ ‏"‏ ‏.‏\hadithno{848}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"By the One in Whose Hand is my soul! I nearly ordered that firewood be gathered to be lit, then I would have ordered that the Adhan be called for prayer, and ordered a man to lead the people in prayer, then I would have gone from behind to those men and burned their houses down over them. By the One in Whose Hand is my soul! If any one of them knew that he would get a meaty bone or some meat in between two ribs, he would attend Isha}}
\hadithdefcmd{nasai}{849}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنِ الْمَسْعُودِيِّ، عَنْ عَلِيِّ بْنِ الأَقْمَرِ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، أَنَّهُ كَانَ يَقُولُ مَنْ سَرَّهُ أَنْ يَلْقَى اللَّهَ عَزَّ وَجَلَّ غَدًا مُسْلِمًا فَلْيُحَافِظْ عَلَى هَؤُلاَءِ الصَّلَوَاتِ الْخَمْسِ حَيْثُ يُنَادَى بِهِنَّ فَإِنَّ اللَّهَ عَزَّ وَجَلَّ شَرَعَ لِنَبِيِّهِ صلى الله عليه وسلم سُنَنَ الْهُدَى وَإِنَّهُنَّ مِنْ سُنَنِ الْهُدَى وَإِنِّي لاَ أَحْسَبُ مِنْكُمْ أَحَدًا إِلاَّ لَهُ مَسْجِدٌ يُصَلِّي فِيهِ فِي بَيْتِهِ فَلَوْ صَلَّيْتُمْ فِي بُيُوتِكُمْ وَتَرَكْتُمْ مَسَاجِدَكُمْ لَتَرَكْتُمْ سُنَّةَ نَبِيِّكُمْ وَلَوْ تَرَكْتُمْ سُنَّةَ نَبِيِّكُمْ لَضَلَلْتُمْ وَمَا مِنْ عَبْدٍ مُسْلِمٍ يَتَوَضَّأُ فَيُحْسِنُ الْوُضُوءَ ثُمَّ يَمْشِي إِلَى صَلاَةٍ إِلاَّ كَتَبَ اللَّهُ عَزَّ وَجَلَّ لَهُ بِكُلِّ خُطْوَةٍ يَخْطُوهَا حَسَنَةً أَوْ يَرْفَعُ لَهُ بِهَا دَرَجَةً أَوْ يُكَفِّرُ عَنْهُ بِهَا خَطِيئَةً وَلَقَدْ رَأَيْتُنَا نُقَارِبُ بَيْنَ الْخُطَا وَلَقَدْ رَأَيْتُنَا وَمَا يَتَخَلَّفُ عَنْهَا إِلاَّ مُنَافِقٌ مَعْلُومٌ نِفَاقُهُ وَلَقَدْ رَأَيْتُ الرَّجُلَ يُهَادَى بَيْنَ الرَّجُلَيْنِ حَتَّى يُقَامَ فِي الصَّفِّ ‏.‏\hadithno{849}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Abdullah said:"Whoever would like to meet Allah tomorrow as a Muslim, let him regularly attend these five (daily) prayers whenever the call for them is given (that in the mosques), for Allah prescribed for His Prophet the ways of guidance, and they (the prayers) are part of those ways of guidance. I do not think that there is anyone among you who does not have a place where he prays in his house. But if you were to pray in your houses and forsake the Masjids, you would be forsaking the Sunnah of your Prophet, and if you were to forsake the Sunnah of your Prophet you would go astray. There is no Muslim slave who performs Wudu and does it well, then walks to the prayer, but Allah will record one Hasanah (good deed) for each step he takes, or raise' him one level by it or erase one sin from him. I remember how we used to take short steps, and I remember (a time) when no one stayed behind from the prayer except a hypocrite whose hypocrisy was well known. And I have seen a man coming Supported by two others until he would be made to stand in the row}}
\hadithdefcmd{nasai}{850}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ الأَصَمِّ، عَنْ عَمِّهِ، يَزِيدَ بْنِ الأَصَمِّ عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ أَعْمَى إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنَّهُ لَيْسَ لِي قَائِدٌ يَقُودُنِي إِلَى الصَّلاَةِ فَسَأَلَهُ أَنْ يُرَخِّصَ لَهُ أَنْ يُصَلِّيَ فِي بَيْتِهِ فَأَذِنَ لَهُ فَلَمَّا وَلَّى دَعَاهُ قَالَ لَهُ ‏"‏ أَتَسْمَعُ النِّدَاءَ بِالصَّلاَةِ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَأَجِبْ ‏"‏ ‏.‏\hadithno{850}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"A blind man came to the Messenger of Allah (ﷺ)and said: 'I do not have a guide to bring me to the prayer.' And he asked him to grant him a dispensation allowing him to pray in his house, and he gave him permission. Then when he turned away he said to him: 'Can you hear the call to prayer?' He said: 'Yes.' He said: 'Then respond to it}}
\hadithdefcmd{nasai}{851}{أَخْبَرَنَا هَارُونُ بْنُ زَيْدِ بْنِ أَبِي الزَّرْقَاءِ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا سُفْيَانُ، ح وَأَخْبَرَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ إِسْحَاقَ، قَالَ حَدَّثَنَا قَاسِمُ بْنُ يَزِيدَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَابِسٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنِ ابْنِ أُمِّ مَكْتُومٍ، أَنَّهُ قَالَ يَا رَسُولَ اللَّهِ إِنَّ الْمَدِينَةَ كَثِيرَةُ الْهَوَامِّ وَالسِّبَاعِ ‏.‏ قَالَ ‏"‏ هَلْ تَسْمَعُ حَىَّ عَلَى الصَّلاَةِ حَىَّ عَلَى الْفَلاَحِ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَحَىَّ هَلاً ‏"‏ ‏.‏ وَلَمْ يُرَخِّصْ لَهُ ‏.‏\hadithno{851}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn Umm Maktum that he said:"0 Messenger of Allah (ﷺ), there are many (dangerous) pests and wild animals in Al-Madinah." He said: "Can you hear (the words) 'Come prayer, come to prosperity'?" He said "Yes." He said: "Then be quick to respond," and he did not grant him a dispensation}}
\hadithdefcmd{nasai}{852}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ عَبْدَ اللَّهِ بْنَ أَرْقَمَ، كَانَ يَؤُمُّ أَصْحَابَهُ فَحَضَرَتِ الصَّلاَةُ يَوْمًا فَذَهَبَ لِحَاجَتِهِ ثُمَّ رَجَعَ فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا وَجَدَ أَحَدُكُمُ الْغَائِطَ فَلْيَبْدَأْ بِهِ قَبْلَ الصَّلاَةِ ‏"‏ ‏.‏\hadithno{852}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Hisham bin 'Urwah from his father that 'Abdullih bin Arqam used to lead his companions in prayer. The time for prayer came one day and he went to relieve himself then he came back and said:"I heard the Messenger of Allah (ﷺ) say: 'If any one of you feels the need to defecate, let him do that first, before he prays}}
\hadithdefcmd{nasai}{853}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا حَضَرَ الْعَشَاءُ وَأُقِيمَتِ الصَّلاَةُ فَابْدَءُوا بِالْعَشَاءِ ‏"‏ ‏.‏\hadithno{853}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah (ﷺ) said: 'If dinner is ready and the Iqamah for prayer is said, then start with dinner first}}
\hadithdefcmd{nasai}{854}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَبِي الْمَلِيحِ، عَنْ أَبِيهِ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِحُنَيْنٍ فَأَصَابَنَا مَطَرٌ فَنَادَى مُنَادِي رَسُولِ اللَّهِ صلى الله عليه وسلم أَنْ صَلُّوا فِي رِحَالِكُمْ ‏.‏\hadithno{854}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Al Malih that his father said:"We were with the Messenger of Allah (ﷺ) in Hunain and it rained. The caller of the Messenger of Allah (ﷺ) called out, telling us: 'Pray where you are}}
\hadithdefcmd{nasai}{855}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنِ ابْنِ طَحْلاَءَ، عَنْ مُحْصِنِ بْنِ عَلِيٍّ الْفِهْرِيِّ، عَنْ عَوْفِ بْنِ الْحَارِثِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ تَوَضَّأَ فَأَحْسَنَ الْوُضُوءَ ثُمَّ خَرَجَ عَامِدًا إِلَى الْمَسْجِدِ فَوَجَدَ النَّاسَ قَدْ صَلَّوْا كَتَبَ اللَّهُ لَهُ مِثْلَ أَجْرِ مَنْ حَضَرَهَا وَلاَ يَنْقُصُ ذَلِكَ مِنْ أُجُورِهِمْ شَيْئًا ‏"‏ ‏.‏\hadithno{855}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"Whoever performs wudu' and does it well, then sets out for the Masjid and finds that the people have already prayed, Allah will decree for him a reward like that of those who attended (the prayer), without reducing the slightest from their reward}}
\hadithdefcmd{nasai}{856}{أَخْبَرَنَا سُلَيْمَانُ بْنُ دَاوُدَ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، أَنَّ الْحُكَيْمَ بْنَ عَبْدِ اللَّهِ الْقُرَشِيَّ، حَدَّثَهُ أَنَّ نَافِعَ بْنَ جُبَيْرٍ وَعَبْدَ اللَّهِ بْنَ أَبِي سَلَمَةَ حَدَّثَاهُ أَنَّ مُعَاذَ بْنَ عَبْدِ الرَّحْمَنِ حَدَّثَهُمَا عَنْ حُمْرَانَ، مَوْلَى عُثْمَانَ بْنِ عَفَّانَ عَنْ عُثْمَانَ بْنِ عَفَّانَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ تَوَضَّأَ لِلصَّلاَةِ فَأَسْبَغَ الْوُضُوءَ ثُمَّ مَشَى إِلَى الصَّلاَةِ الْمَكْتُوبَةِ فَصَلاَّهَا مَعَ النَّاسِ أَوْ مَعَ الْجَمَاعَةِ أَوْ فِي الْمَسْجِدِ غَفَرَ اللَّهُ لَهُ ذُنُوبَهُ ‏"‏ ‏.‏\hadithno{856}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Uthman bin 'Affan said:"I heard the Messenger of Allah (ﷺ) say: 'Whoever does wudu' properly, then walks to (attend) the prescribed prayer, and prays with the people or with the congregation or in the Masjid, Allah will forgive him his sins}}
\hadithdefcmd{nasai}{857}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنِ زَيْدِ بْنِ أَسْلَمَ، عَنْ رَجُلٍ، مِنْ بَنِي الدِّيلِ يُقَالُ لَهُ بُسْرُ بْنُ مِحْجَنٍ عَنْ مِحْجَنٍ، أَنَّهُ كَانَ فِي مَجْلِسٍ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَذَّنَ بِالصَّلاَةِ - فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ رَجَعَ وَمِحْجَنٌ فِي مَجْلِسِهِ - فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا مَنَعَكَ أَنْ تُصَلِّيَ أَلَسْتَ بِرَجُلٍ مُسْلِمٍ ‏"‏ ‏.‏ قَالَ بَلَى وَلَكِنِّي كُنْتُ قَدْ صَلَّيْتُ فِي أَهْلِي فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا جِئْتَ فَصَلِّ مَعَ النَّاسِ وَإِنْ كُنْتَ قَدْ صَلَّيْتَ ‏"‏ ‏.‏\hadithno{857}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Mihjan that he was in a gathering with the Messenger of Allah (ﷺ) when the Adhan was called for prayer. The A Messenger of Allah (ﷺ) got up, then he came back and Mihjan was still sitting there. The Messenger of Allah (ﷺ) said to him:"What kept you from praying? Are you not a Muslim man?" He said: "Yes, but I had already prayed with my family." The Messenger of Allah (ﷺ)said to him: "When you come you should pray with the people even if you have already prayed}}
\hadithdefcmd{nasai}{858}{أَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ حَدَّثَنَا يَعْلَى بْنُ عَطَاءٍ، قَالَ حَدَّثَنَا جَابِرُ بْنُ يَزِيدَ بْنِ الأَسْوَدِ الْعَامِرِيُّ، عَنْ أَبِيهِ، قَالَ شَهِدْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم صَلاَةَ الْفَجْرِ فِي مَسْجِدِ الْخَيْفِ فَلَمَّا قَضَى صَلاَتَهُ إِذَا هُوَ بِرَجُلَيْنِ فِي آخِرِ الْقَوْمِ لَمْ يُصَلِّيَا مَعَهُ قَالَ ‏"‏ عَلَىَّ بِهِمَا ‏"‏ ‏.‏ فَأُتِيَ بِهِمَا تُرْعَدُ فَرَائِصُهُمَا فَقَالَ ‏"‏ مَا مَنَعَكُمَا أَنْ تُصَلِّيَا مَعَنَا ‏"‏ ‏.‏ قَالاَ يَا رَسُولَ اللَّهِ إِنَّا قَدْ صَلَّيْنَا فِي رِحَالِنَا ‏.‏ قَالَ ‏"‏ فَلاَ تَفْعَلاَ إِذَا صَلَّيْتُمَا فِي رِحَالِكُمَا ثُمَّ أَتَيْتُمَا مَسْجِدَ جَمَاعَةٍ فَصَلِّيَا مَعَهُمْ فَإِنَّهَا لَكُمَا نَافِلَةٌ ‏"‏ ‏.‏\hadithno{858}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{Jabir bin Yazid bin Al-Aswad Al Amir told us that his father said:"I attended Fajr prayer with the Messenger of Allah (ﷺ)in Masjid Al Khaif. When he finished praying, he saw two men at the back of the people who had not prayed with him. He said: 'Bring them here.' So they were brought to him, trembling. He said: 'What kept you from praying with us? They said: '0 Messenger of Allah (ﷺ) we has already prayed in our lodgings.' He said: 'Do not do that. If you have already prayed in your lodgings, then you come to a Masjid in which there is a congregation, then pray with them, and it will be a voluntary prayer for you}}
\hadithdefcmd{nasai}{859}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، وَمُحَمَّدُ بْنُ إِبْرَاهِيمَ بْنِ صُدْرَانَ، - وَاللَّفْظُ لَهُ - عَنْ خَالِدِ بْنِ الْحَارِثِ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ بُدَيْلٍ، قَالَ سَمِعْتُ أَبَا الْعَالِيَةِ، يُحَدِّثُ عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَضَرَبَ فَخِذِي ‏"‏ كَيْفَ أَنْتَ إِذَا بَقِيتَ فِي قَوْمٍ يُؤَخِّرُونَ الصَّلاَةَ عَنْ وَقْتِهَا ‏"‏ ‏.‏ قَالَ مَا تَأْمُرُ قَالَ ‏"‏ صَلِّ الصَّلاَةَ لِوَقْتِهَا ثُمَّ اذْهَبْ لِحَاجَتِكَ فَإِنْ أُقِيمَتِ الصَّلاَةُ وَأَنْتَ فِي الْمَسْجِدِ فَصَلِّ ‏"‏ ‏.‏\hadithno{859}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ahu Dharr said:"The Messenger of Allah (ﷺ) said to me, and struck my thigh: 'What will you do if you stay among people who delay the prayer until its time is over?' He said: 'What do you command me to do?' He said: 'Offer the prayer on time, then go about your business. Then if the Iqamah for that prayer is said and you are in the Masjid, then pray}}
\hadithdefcmd{nasai}{860}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ مُحَمَّدٍ التَّيْمِيُّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ حُسَيْنٍ الْمُعَلِّمِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ سُلَيْمَانَ، مَوْلَى مَيْمُونَةَ قَالَ رَأَيْتُ ابْنَ عُمَرَ جَالِسًا عَلَى الْبَلاَطِ وَالنَّاسُ يُصَلُّونَ قُلْتُ يَا أَبَا عَبْدِ الرَّحْمَنِ مَا لَكَ لاَ تُصَلِّي قَالَ إِنِّي قَدْ صَلَّيْتُ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تُعَادُ الصَّلاَةُ فِي يَوْمٍ مَرَّتَيْنِ ‏"‏ ‏.‏\hadithno{860}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Sulaiman - the freed slave of Maimunah - said:"I saw Ibn 'Umar sitting in Al-Balat when the people were praying. I said: '0 Abu 'Abdur- Rahman, why are you not praying?' He said: 'I have already prayed, and I heard the Messenger of Allah (ﷺ) say: "Do not repeat a prayer twice in one day}}
\hadithdefcmd{nasai}{861}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ الزُّهْرِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَتَيْتُمُ الصَّلاَةَ فَلاَ تَأْتُوهَا وَأَنْتُمْ تَسْعَوْنَ وَأْتُوهَا تَمْشُونَ وَعَلَيْكُمُ السَّكِينَةُ فَمَا أَدْرَكْتُمْ فَصَلُّوا وَمَا فَاتَكُمْ فَاقْضُوا ‏"‏ ‏.‏\hadithno{861}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of (ﷺ) said: 'When you come to pray, do not come rushing; come walking in a dignified manner, and whatever you catch up with, pray, and whatever you miss, make it up}}
\hadithdefcmd{nasai}{862}{أَخْبَرَنَا عَمْرُو بْنُ سَوَّادِ بْنِ الأَسْوَدِ بْنِ عَمْرٍو، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ أَنْبَأَنَا ابْنُ جُرَيْجٍ، عَنْ مَنْبُوذٍ، عَنِ الْفَضْلِ بْنِ عُبَيْدِ اللَّهِ، عَنْ أَبِي رَافِعٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا صَلَّى الْعَصْرَ ذَهَبَ إِلَى بَنِي عَبْدِ الأَشْهَلِ فَيَتَحَدَّثُ عِنْدَهُمْ حَتَّى يَنْحَدِرَ لِلْمَغْرِبِ ‏.‏ قَالَ أَبُو رَافِعٍ فَبَيْنَمَا النَّبِيُّ صلى الله عليه وسلم يُسْرِعُ إِلَى الْمَغْرِبِ مَرَرْنَا بِالْبَقِيعِ فَقَالَ ‏"‏ أُفٍّ لَكَ أُفٍّ لَكَ ‏"‏ ‏.‏ قَالَ فَكَبُرَ ذَلِكَ فِي ذَرْعِي فَاسْتَأْخَرْتُ وَظَنَنْتُ أَنَّهُ يُرِيدُنِي فَقَالَ ‏"‏ مَا لَكَ امْشِ ‏"‏ ‏.‏ فَقُلْتُ أَحْدَثْتُ حَدَثًا ‏.‏ قَالَ ‏"‏ مَا ذَاكَ ‏"‏ ‏.‏ قُلْتُ أَفَّفْتَ بِي ‏.‏ قَالَ ‏"‏ لاَ وَلَكِنْ هَذَا فُلاَنٌ بَعَثْتُهُ سَاعِيًا عَلَى بَنِي فُلاَنٍ فَغَلَّ نَمِرَةً فَدُرِّعَ الآنَ مِثْلَهَا مِنْ نَارٍ ‏"‏ ‏.‏\hadithno{862}\hadithgrade{Abu Ghuddah: Hasan Isnaad; Al-Albani: Hasan Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Rafi said:"After the Messenger of Allah (ﷺ) had prayed Asr, he would go to Banu 'Abdul-Ashhal to speak to them, until the time for Maghrib came." Abu Rafi said: "While the Prophet (ﷺ) was hastening to pray Maghrib, we passed by and he said: 'Fie on you, fie on you!' That upset me so I slowed down because I thought hat he meant me. He said: 'What is the matter with you? Keep up!' I said: 'Is there something wrong?' He said: 'Why are you asking that? I said: 'Because you said: "Fie on you" to me.' He said: 'No, that was so-and-so whom I had sent to collect Zakat from the tribe of so-and-so, and he stole a Namirah and now he is clothed with something similar made of Fire}}
\hadithdefcmd{nasai}{863}{أَخْبَرَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمْرٍو، قَالَ حَدَّثَنَا أَبُو إِسْحَاقَ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي مَنْبُوذٌ، - رَجُلٌ مِنْ آلِ أَبِي رَافِعٍ - عَنِ الْفَضْلِ بْنِ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ، عَنْ أَبِي رَافِعٍ، نَحْوَهُ ‏.‏\hadithno{863}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{(Another chain) with similar from Abu Rafi}}
\hadithdefcmd{nasai}{864}{أَخْبَرَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ الْمُغِيرَةِ، قَالَ حَدَّثَنَا عُثْمَانُ، عَنْ شُعَيْبٍ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، وَأَبُو عَبْدِ اللَّهِ الأَغَرُّ، أَنَّ أَبَا هُرَيْرَةَ، حَدَّثَهُمَا ‏.‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّمَا مَثَلُ الْمُهَجِّرِ إِلَى الصَّلاَةِ كَمَثَلِ الَّذِي يُهْدِي الْبَدَنَةَ ثُمَّ الَّذِي عَلَى إِثْرِهِ كَالَّذِي يُهْدِي الْبَقَرَةَ ثُمَّ الَّذِي عَلَى إِثْرِهِ كَالَّذِي يُهْدِي الْكَبْشَ ثُمَّ الَّذِي عَلَى إِثْرِهِ كَالَّذِي يُهْدِي الدَّجَاجَةَ ثُمَّ الَّذِي عَلَى إِثْرِهِ كَالَّذِي يُهْدِي الْبَيْضَةَ ‏"‏ ‏.‏\hadithno{864}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (ﷺ) said:"The likeness of one who comes early to prayer is that of one who sacrificed a camel, then the one who comes after him is like one who sacrificed a cow, then the one who comes after him is like one who sacrificed a ram, then the one who comes after him is like one who sacrificed a chicken, then the one who comes after him is like one who sacrificed an egg}}
\hadithdefcmd{nasai}{865}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ زَكَرِيَّا، قَالَ حَدَّثَنِي عَمْرُو بْنُ دِينَارٍ، قَالَ سَمِعْتُ عَطَاءَ بْنَ يَسَارٍ، يُحَدِّثُ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أُقِيمَتِ الصَّلاَةُ فَلاَ صَلاَةَ إِلاَّ الْمَكْتُوبَةُ ‏"‏ ‏.‏\hadithno{865}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) aid: 'When the Iqamah for prayer is said, there is no prayer except the prescribed prayer}}
\hadithdefcmd{nasai}{866}{أَخْبَرَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ الْحَكَمِ، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدٌ، عَنْ شُعْبَةَ، عَنْ وَرْقَاءَ بْنِ عُمَرَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أُقِيمَتِ الصَّلاَةُ فَلاَ صَلاَةَ إِلاَّ الْمَكْتُوبَةُ ‏"‏ ‏.‏\hadithno{866}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:"When the Iqamah for prayer is said, there is no prayer except the prescribed prayer}}
\hadithdefcmd{nasai}{867}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنِ ابْنِ بُحَيْنَةَ، قَالَ أُقِيمَتْ صَلاَةُ الصُّبْحِ فَرَأَى رَسُولُ اللَّهِ صلى الله عليه وسلم رَجُلاً يُصَلِّي وَالْمُؤَذِّنُ يُقِيمُ فَقَالَ ‏ "‏ أَتُصَلِّي الصُّبْحَ أَرْبَعًا ‏"‏ ‏.‏\hadithno{867}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn Buhainah said:"The Iqamah for Subh prayer was said, and the Messenger of Allah (ﷺ) saw a man praying while the Mu'adhdhin saying the Iqamah. He said: 'Are you praying Subh with four Rak'ahs?}}
\hadithdefcmd{nasai}{868}{أَخْبَرَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، قَالَ حَدَّثَنَا حَمَّادٌ، قَالَ حَدَّثَنَا عَاصِمٌ، عَنْ عَبْدِ اللَّهِ بْنِ سَرْجِسَ، قَالَ جَاءَ رَجُلٌ وَرَسُولُ اللَّهِ صلى الله عليه وسلم فِي صَلاَةِ الصُّبْحِ فَرَكَعَ الرَّكْعَتَيْنِ ثُمَّ دَخَلَ فَلَمَّا قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم صَلاَتَهُ قَالَ ‏ "‏ يَا فُلاَنُ أَيُّهُمَا صَلاَتُكَ الَّتِي صَلَّيْتَ مَعَنَا أَوِ الَّتِي صَلَّيْتَ لِنَفْسِكَ ‏"‏ ‏.‏\hadithno{868}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Abdullah bin Sarjis said:"A man came while the Messenger of Allah (ﷺ) was praying Subh, and he prayed two Rak'ahs then joined the prayer. When the Messenger of Allah (ﷺ) had finished praying he said: O so-and-so, which of them is your prayer - the one you prayed with us or the one you prayed on your own?}}
\hadithdefcmd{nasai}{869}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي إِسْحَاقُ بْنُ عَبْدِ اللَّهِ، قَالَ سَمِعْتُ أَنَسًا، - رضى الله عنه - قَالَ أَتَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي بَيْتِنَا فَصَلَّيْتُ أَنَا وَيَتِيمٌ لَنَا خَلْفَهُ وَصَلَّتْ أُمُّ سُلَيْمٍ خَلْفَنَا ‏.‏\hadithno{869}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Anas said:"The Messenger of Allah (ﷺ) came to our house and I prayed with an orphan of ours behind him, and Umm Sulaim prayed behind us}}
\hadithdefcmd{nasai}{870}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا نُوحٌ، - يَعْنِي ابْنَ قَيْسٍ - عَنِ ابْنِ مَالِكٍ، - وَهُوَ عَمْرٌو - عَنْ أَبِي الْجَوْزَاءِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَتِ امْرَأَةٌ تُصَلِّي خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم حَسْنَاءُ مِنْ أَحْسَنِ النَّاسِ - قَالَ - فَكَانَ بَعْضُ الْقَوْمِ يَتَقَدَّمُ فِي الصَّفِّ الأَوَّلِ لِئَلاَّ يَرَاهَا وَيَسْتَأْخِرُ بَعْضُهُمْ حَتَّى يَكُونَ فِي الصَّفِّ الْمُؤَخَّرِ فَإِذَا رَكَعَ نَظَرَ مِنْ تَحْتِ إِبْطِهِ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ وَلَقَدْ عَلِمْنَا الْمُسْتَقْدِمِينَ مِنْكُمْ وَلَقَدْ عَلِمْنَا الْمُسْتَأْخِرِينَ ‏\}‏ ‏.‏\hadithno{870}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn Abbas said:"There was a woman who used to pray behind the Messenger of Allah (ﷺ) who was beautiful, one of the most beautiful of people. Some of the people used to go to the front row to avoid seeing her, and some used to go to the back row so that when they bowed they could see her from beneath their armpits. Then Allah revealed the words: 'To Us are known those of you who hasten forward and those who lag behind}}
\hadithdefcmd{nasai}{871}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، عَنْ يَزِيدَ بْنِ زُرَيْعٍ، قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ زِيَادٍ الأَعْلَمِ، قَالَ حَدَّثَنَا الْحَسَنُ، أَنَّ أَبَا بَكْرَةَ، حَدَّثَهُ أَنَّهُ، دَخَلَ الْمَسْجِدَ وَالنَّبِيُّ صلى الله عليه وسلم رَاكِعٌ فَرَكَعَ دُونَ الصَّفِّ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ زَادَكَ اللَّهُ حِرْصًا وَلاَ تَعُدْ ‏"‏ ‏.‏\hadithno{871}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abu Bakrah narrated that he entered the Masjid when the when the Prophet (ﷺ) was bowing, so he bowed outside the row. The Prophet said:"May Allah increase you in keenness, but do not do this again}}
\hadithdefcmd{nasai}{872}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنِي أَبُو أُسَامَةَ، قَالَ حَدَّثَنِي الْوَلِيدُ بْنُ كَثِيرٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمًا ثُمَّ انْصَرَفَ فَقَالَ ‏ "‏ يَا فُلاَنُ أَلاَ تُحَسِّنُ صَلاَتَكَ أَلاَ يَنْظُرُ الْمُصَلِّي كَيْفَ يُصَلِّي لِنَفْسِهِ إِنِّي أُبْصِرُ مِنْ وَرَائِي كَمَا أُبْصِرُ بَيْنَ يَدَىَّ ‏"‏ ‏.‏\hadithno{872}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) prayed one day then left and said: '0 so-and-so, why don't you improve your prayer? Shouldn't the one who is praying reflection how he prays it for himself? I can see behind me just as I can see in front of me}}
\hadithdefcmd{nasai}{873}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي قَبْلَ الظُّهْرِ رَكْعَتَيْنِ وَبَعْدَهَا رَكْعَتَيْنِ وَكَانَ يُصَلِّي بَعْدَ الْمَغْرِبِ رَكْعَتَيْنِ فِي بَيْتِهِ وَبَعْدَ الْعِشَاءِ رَكْعَتَيْنِ وَكَانَ لاَ يُصَلِّي بَعْدَ الْجُمُعَةِ حَتَّى يَنْصَرِفَ فَيُصَلِّيَ رَكْعَتَيْنِ ‏.‏\hadithno{873}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah (ﷺ) used to pray two Rak'ahs before Zuhr and two afterward, and he used to pray two Rak'ahs after Maghrib in his house, and two Rak'ahs after 'Isha', and he did not pray after Jumu'ah until he departed (from the Masjid), then he would pray two Rak'ahs at home}}
\hadithdefcmd{nasai}{874}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَاصِمِ بْنِ ضَمْرَةَ، قَالَ سَأَلْنَا عَلِيًّا عَنْ صَلاَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ أَيُّكُمْ يُطِيقُ ذَلِكَ قُلْنَا إِنْ لَمْ نُطِقْهُ سَمِعْنَا ‏.‏ قَالَ كَانَ إِذَا كَانَتِ الشَّمْسُ مِنْ هَا هُنَا كَهَيْئَتِهَا مِنْ هَا هُنَا عِنْدَ الْعَصْرِ صَلَّى رَكْعَتَيْنِ فَإِذَا كَانَتْ مِنْ هَا هُنَا كَهَيْئَتِهَا مِنْ هَا هُنَا عِنْدَ الظُّهْرِ صَلَّى أَرْبَعًا وَيُصَلِّي قَبْلَ الظُّهْرِ أَرْبَعًا وَبَعْدَهَا ثِنْتَيْنِ وَيُصَلِّي قَبْلَ الْعَصْرِ أَرْبَعًا يَفْصِلُ بَيْنَ كُلِّ رَكْعَتَيْنِ بِتَسْلِيمٍ عَلَى الْمَلاَئِكَةِ الْمُقَرَّبِينَ وَالنَّبِيِّينَ وَمَنْ تَبِعَهُمْ مِنَ الْمُؤْمِنِينَ وَالْمُسْلِمِينَ ‏.‏\hadithno{874}\hadithgrade{Abu Ghuddah: -; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Ishaq, that 'Asim bin Damrah said:"We asked 'Ali about the prayer of the Messenger of Allah (ﷺ). He said: 'Who among you could manage to do that?' We said: 'Even if we cannot do it, we still want to hear about it.' He said: 'When the sun reached the same height (in the east) as it reaches (in the west) at the time of 'Asr, he would pray two rak'ahs, and when the sun reached the same height (in the east) as it reaches (in the west) at the time for Zuhr he would pray four Rak'ahs. He would pray four Rak'ahs before Zuhr and two after, and he would pray four Rak'ahs before 'Asr, separating each two Rak'ahs with Taslim upon the angels who are close to Allah, and the prophets, and those who follow them of the believers and Muslims}}
\hadithdefcmd{nasai}{875}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا حُصَيْنُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَاصِمِ بْنِ ضَمْرَةَ، قَالَ سَأَلْتُ عَلِيَّ بْنَ أَبِي طَالِبٍ عَنْ صَلاَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم فِي النَّهَارِ قَبْلَ الْمَكْتُوبَةِ قَالَ مَنْ يُطِيقُ ذَلِكَ ثُمَّ أَخْبَرَنَا قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي حِينَ تَزِيغُ الشَّمْسُ رَكْعَتَيْنِ وَقَبْلَ نِصْفِ النَّهَارِ أَرْبَعَ رَكَعَاتٍ يَجْعَلُ التَّسْلِيمَ فِي آخِرِهِ ‏.‏\hadithno{875}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Ishaq, that Asim bin Damrah said:"I asked 'Ali bin Abi Talib about the prayer of the Messenger of Allah (ﷺ) during the day before the prescribed prayers. He said: 'Who is able to do that?' Then he told us:'The Messenger of Allah (ﷺ) used to pray two Rak'ahs when the sun had passed its zenith, and four Rak'ahs before the middle of the day, with the Taslim at the end}}
